# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.broadcast.v1 import push_pb2 as bilibili_dot_broadcast_dot_v1_dot_push__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class PushStub(object):
    """Push
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WatchMessage = channel.unary_stream(
                '/bilibili.broadcast.v1.Push/WatchMessage',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_v1_dot_push__pb2.PushMessageResp.FromString,
                )


class PushServicer(object):
    """Push
    """

    def WatchMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PushServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'WatchMessage': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchMessage,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_v1_dot_push__pb2.PushMessageResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.broadcast.v1.Push', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Push(object):
    """Push
    """

    @staticmethod
    def WatchMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/bilibili.broadcast.v1.Push/WatchMessage',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bilibili_dot_broadcast_dot_v1_dot_push__pb2.PushMessageResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
