# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.pgc.service.premiere.v1 import premiere_pb2 as bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2


class PremiereStub(object):
    """首播服务
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Status = channel.unary_unary(
                '/bilibili.pgc.service.premiere.v1.Premiere/Status',
                request_serializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReq.SerializeToString,
                response_deserializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReply.FromString,
                )


class PremiereServicer(object):
    """首播服务
    """

    def Status(self, request, context):
        """获取首播状态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PremiereServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReq.FromString,
                    response_serializer=bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.pgc.service.premiere.v1.Premiere', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Premiere(object):
    """首播服务
    """

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pgc.service.premiere.v1.Premiere/Status',
            bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReq.SerializeToString,
            bilibili_dot_pgc_dot_service_dot_premiere_dot_v1_dot_premiere__pb2.PremiereStatusReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
