# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/editor/notify.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.bilibili/broadcast/message/editor/notify.proto\x12!bilibili.broadcast.message.editor\x1a\x1bgoogle/protobuf/empty.proto\"\xa6\x01\n\x06Notify\x12\x0e\n\x06msg_id\x18\x01 \x01(\x03\x12\x10\n\x08msg_type\x18\x02 \x01(\x05\x12\x14\n\x0creceiver_uid\x18\x03 \x01(\x03\x12\x15\n\rreceiver_type\x18\x04 \x01(\x05\x12\x15\n\rstory_version\x18\x05 \x01(\x03\x12\x0f\n\x07op_hash\x18\x06 \x01(\x03\x12\x11\n\top_sender\x18\x07 \x01(\x03\x12\x12\n\nop_content\x18\x08 \x01(\t2i\n\x0fOperationNotify\x12V\n\x0fOperationNotify\x12\x16.google.protobuf.Empty\x1a).bilibili.broadcast.message.editor.Notify0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.editor.notify_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFY._serialized_start=115
  _NOTIFY._serialized_end=281
  _OPERATIONNOTIFY._serialized_start=283
  _OPERATIONNOTIFY._serialized_end=388
# @@protoc_insertion_point(module_scope)
