# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/space/v1/space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/app/space/v1/space.proto\x12\x15\x62ilibili.app.space.v1\"\xc5\x01\n\x0c\x41rchiveReply\x12\x33\n\x04item\x18\x01 \x03(\x0b\x32%.bilibili.app.space.v1.BiliSpaceVideo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12>\n\x0f\x65pisodic_button\x18\x03 \x01(\x0b\x32%.bilibili.app.space.v1.EpisodicButton\x12\x31\n\x05order\x18\x04 \x03(\x0b\x32\".bilibili.app.space.v1.OrderConfig\"A\n\nArchiveReq\x12\x0c\n\x04vmid\x18\x01 \x01(\x03\x12\n\n\x02pn\x18\x02 \x01(\x05\x12\n\n\x02ps\x18\x03 \x01(\x05\x12\r\n\x05order\x18\x04 \x01(\t\"\xb1\x01\n\x05\x42\x61\x64ge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\"\xcb\x02\n\x0e\x42iliSpaceVideo\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05tname\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\r\n\x05\x63over\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\r\n\x05param\x18\x06 \x01(\t\x12\x0f\n\x07\x64\x61nmaku\x18\x07 \x01(\t\x12\x0c\n\x04play\x18\x08 \x01(\x05\x12\r\n\x05\x63time\x18\t \x01(\x03\x12\r\n\x05state\x18\n \x01(\x08\x12\x12\n\nis_popular\x18\x0b \x01(\x08\x12,\n\x06\x62\x61\x64ges\x18\x0c \x03(\x0b\x32\x1c.bilibili.app.space.v1.Badge\x12\x13\n\x0b\x63over_right\x18\r \x01(\t\x12\x0c\n\x04\x62vid\x18\x0e \x01(\t\x12\x11\n\tis_steins\x18\x0f \x01(\x08\x12\x11\n\tis_ugcpay\x18\x10 \x01(\x08\x12\x16\n\x0eis_cooperation\x18\x11 \x01(\x08\"+\n\x0e\x45pisodicButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"+\n\x0bOrderConfig\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2Z\n\x05Space\x12Q\n\x07\x41rchive\x12!.bilibili.app.space.v1.ArchiveReq\x1a#.bilibili.app.space.v1.ArchiveReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.space.v1.space_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ARCHIVEREPLY._serialized_start=61
  _ARCHIVEREPLY._serialized_end=258
  _ARCHIVEREQ._serialized_start=260
  _ARCHIVEREQ._serialized_end=325
  _BADGE._serialized_start=328
  _BADGE._serialized_end=505
  _BILISPACEVIDEO._serialized_start=508
  _BILISPACEVIDEO._serialized_end=839
  _EPISODICBUTTON._serialized_start=841
  _EPISODICBUTTON._serialized_end=884
  _ORDERCONFIG._serialized_start=886
  _ORDERCONFIG._serialized_end=929
  _SPACE._serialized_start=931
  _SPACE._serialized_end=1021
# @@protoc_insertion_point(module_scope)
