# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/ad/v1/ad.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x62ilibili/ad/v1/ad.proto\x12\x0e\x62ilibili.ad.v1\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x8f\x02\n\x12\x41\x64\x41utoPlayVideoDto\x12\x0c\n\x04\x61vid\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x11\n\tauto_play\x18\x07 \x01(\x08\x12\x15\n\rbtn_dyc_color\x18\x08 \x01(\x08\x12\x14\n\x0c\x62tn_dyc_time\x18\t \x01(\x05\x12\x0e\n\x06\x62iz_id\x18\n \x01(\x03\x12\x15\n\rprocess0_urls\x18\x0b \x03(\t\x12\x14\n\x0cplay_3s_urls\x18\x0c \x03(\t\x12\x14\n\x0cplay_5s_urls\x18\r \x03(\t\x12\x13\n\x0borientation\x18\x0e \x01(\x05\"\x8a\x02\n\x11\x41\x64\x42usinessMarkDto\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\x12\x18\n\x10text_color_night\x18\x04 \x01(\t\x12\x10\n\x08\x62g_color\x18\x05 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x06 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x07 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x08 \x01(\t\x12\x0f\n\x07img_url\x18\t \x01(\t\x12\x12\n\nimg_height\x18\n \x01(\x05\x12\x11\n\timg_width\x18\x0b \x01(\x05\x12\x17\n\x0f\x62g_border_color\x18\x0c \x01(\t\"\xcc\x01\n\x0b\x41\x64\x42uttonDto\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x13\n\x0breport_urls\x18\x04 \x01(\t\x12\x18\n\x10\x64lsuc_callup_url\x18\x05 \x01(\t\x12\x0f\n\x07game_id\x18\x06 \x01(\x05\x12\x1a\n\x12game_monitor_param\x18\x07 \x01(\t\x12\x17\n\x0fgame_channel_id\x18\x08 \x01(\x05\x12\x1a\n\x12game_channel_extra\x18\t \x01(\t\"\xef\r\n\tAdCardDto\x12\x11\n\tcard_type\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x12\n\nextra_desc\x18\x04 \x01(\t\x12\x11\n\tlong_desc\x18\x05 \x01(\t\x12\x13\n\x0bshort_title\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x61nmu_title\x18\x07 \x01(\t\x12\x14\n\x0c\x64\x61nmu_height\x18\x08 \x01(\x05\x12\x13\n\x0b\x64\x61nmu_width\x18\t \x01(\x05\x12\x12\n\ndanmu_life\x18\n \x01(\x05\x12\x13\n\x0b\x64\x61nmu_begin\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x61nmu_color\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x61nmu_h5url\x18\r \x01(\t\x12\x12\n\ndanmu_icon\x18\x0e \x01(\t\x12\x11\n\tfold_time\x18\x0f \x01(\x05\x12\x0e\n\x06\x61\x64_tag\x18\x10 \x01(\t\x12*\n\x06\x63overs\x18\x11 \x03(\x0b\x32\x1a.bilibili.ad.v1.AdCoverDto\x12\x10\n\x08jump_url\x18\x12 \x01(\t\x12%\n\x1dimax_landing_page_json_string\x18\x13 \x01(\t\x12\x12\n\ncallup_url\x18\x14 \x01(\t\x12\x15\n\runiversal_app\x18\x15 \x01(\t\x12\x11\n\tori_price\x18\x16 \x01(\t\x12\x11\n\tcur_price\x18\x17 \x01(\x05\x12\x12\n\nprice_desc\x18\x18 \x01(\t\x12\x14\n\x0cprice_symbol\x18\x19 \x01(\t\x12\x17\n\x0fgoods_cur_price\x18\x1a \x01(\t\x12\x17\n\x0fgoods_ori_price\x18\x1b \x01(\t\x12\'\n\x04good\x18\x1c \x01(\x0b\x32\x19.bilibili.ad.v1.AdGoodDto\x12\x0c\n\x04rank\x18\x1d \x01(\x05\x12\x11\n\thot_score\x18\x1e \x01(\x05\x12+\n\x06\x62utton\x18\x1f \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12\x12\n\nadver_logo\x18  \x01(\t\x12\x12\n\nadver_name\x18! \x01(\t\x12\x16\n\x0e\x61\x64ver_page_url\x18\" \x01(\t\x12\x15\n\rvideo_barrage\x18# \x03(\t\x12\x37\n\x0c\x61\x64_tag_style\x18$ \x01(\x0b\x32!.bilibili.ad.v1.AdBusinessMarkDto\x12\x31\n\x05video\x18% \x01(\x0b\x32\".bilibili.ad.v1.AdAutoPlayVideoDto\x12:\n\x0e\x66\x65\x65\x64\x62\x61\x63k_panel\x18& \x01(\x0b\x32\".bilibili.ad.v1.AdFeedbackPanelDto\x12\x11\n\tadver_mid\x18\' \x01(\x03\x12\x18\n\x10\x61\x64ver_account_id\x18( \x01(\x03\x12\x10\n\x08\x64uration\x18) \x01(\t\x12\x32\n\rquality_infos\x18* \x03(\x0b\x32\x1b.bilibili.ad.v1.QualityInfo\x12\x14\n\x0c\x64ynamic_text\x18+ \x01(\t\x12\'\n\x05\x61\x64ver\x18, \x01(\x0b\x32\x18.bilibili.ad.v1.AdverDto\x12\x13\n\x0bgrade_level\x18- \x01(\x05\x12\x1a\n\x12support_transition\x18. \x01(\x08\x12\x12\n\ntransition\x18/ \x01(\t\x12&\n\x1eunder_player_interaction_style\x18\x30 \x01(\x05\x12\x1c\n\x14imax_landing_page_v2\x18\x31 \x01(\t\x12\x35\n\x0esubcard_module\x18\x32 \x01(\x0b\x32\x1d.bilibili.ad.v1.SubCardModule\x12\x19\n\x11grade_denominator\x18\x33 \x01(\x05\x12\x12\n\nstar_level\x18\x34 \x01(\x05\x12*\n\x08\x62ulletin\x18\x35 \x01(\x0b\x32\x18.bilibili.ad.v1.Bulletin\x12\"\n\x04gift\x18\x36 \x01(\x0b\x32\x14.bilibili.ad.v1.Gift\x12\x11\n\tgame_tags\x18\x37 \x03(\t\x12\x17\n\x0fori_mark_hidden\x18\x38 \x01(\x05\x12\x17\n\x0fuse_multi_cover\x18\x39 \x01(\x08\x12\x36\n\x0fwx_program_info\x18: \x01(\x0b\x32\x1d.bilibili.ad.v1.WxProgramInfo\x12\x41\n\x15\x61ndroid_game_page_res\x18; \x01(\x0b\x32\".bilibili.ad.v1.AndroidGamePageRes\x12<\n\x12not_clickable_area\x18< \x01(\x0b\x32 .bilibili.ad.v1.NotClickableArea\x12\x33\n\rforward_reply\x18= \x01(\x0b\x32\x1c.bilibili.ad.v1.ForwardReply\"\xb5\t\n\x11\x41\x64\x43ontentExtraDto\x12\x0e\n\x06layout\x18\x01 \x01(\t\x12\x11\n\tshow_urls\x18\x02 \x03(\t\x12\x12\n\nclick_urls\x18\x03 \x03(\t\x12\x1c\n\x14\x64\x61nmu_list_show_urls\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x61nmu_list_click_urls\x18\x05 \x03(\t\x12\x1e\n\x16\x64\x61nmu_detail_show_urls\x18\x06 \x03(\t\x12\x1e\n\x16\x64\x61nmu_trolley_add_urls\x18\x07 \x03(\t\x12\x15\n\ruse_ad_web_v2\x18\x08 \x01(\x08\x12\x16\n\x0eopen_whitelist\x18\t \x03(\t\x12\x39\n\x12\x64ownload_whitelist\x18\n \x01(\x0b\x32\x1d.bilibili.ad.v1.AppPackageDto\x12\'\n\x04\x63\x61rd\x18\x0b \x01(\x0b\x32\x19.bilibili.ad.v1.AdCardDto\x12\x13\n\x0breport_time\x18\x0c \x01(\x05\x12\x19\n\x11\x61ppstore_priority\x18\r \x01(\x05\x12\x12\n\nsales_type\x18\x0e \x01(\x05\x12\x1b\n\x13preload_landingpage\x18\x0f \x01(\x05\x12\x18\n\x10special_industry\x18\x10 \x01(\x08\x12\x1d\n\x15special_industry_tips\x18\x11 \x01(\t\x12\x1e\n\x16\x65nable_download_dialog\x18\x12 \x01(\x08\x12\x14\n\x0c\x65nable_share\x18\x13 \x01(\x08\x12\x1c\n\x14upzone_entrance_type\x18\x14 \x01(\x05\x12!\n\x19upzone_entrance_report_id\x18\x15 \x01(\x05\x12\x32\n\nshare_info\x18\x16 \x01(\x0b\x32\x1e.bilibili.ad.v1.AdShareInfoDto\x12\x17\n\x0ftopview_pic_url\x18\x17 \x01(\t\x12\x19\n\x11topview_video_url\x18\x18 \x01(\t\x12\x12\n\nclick_area\x18\x19 \x01(\x05\x12\x0f\n\x07shop_id\x18\x1a \x01(\x03\x12\x0e\n\x06up_mid\x18\x1b \x01(\x03\x12\x10\n\x08track_id\x18\x1c \x01(\t\x12\"\n\x1a\x65nable_store_direct_launch\x18\x1d \x01(\x05\x12\x12\n\nproduct_id\x18\x1e \x01(\x03\x12\x1a\n\x12\x65nable_double_jump\x18\x1f \x01(\x08\x12\x13\n\x0bshow1s_urls\x18  \x03(\t\x12\x15\n\rfrom_track_id\x18! \x01(\t\x12\x19\n\x11store_callup_card\x18\" \x01(\x08\x12\"\n\x1alandingpage_download_style\x18# \x01(\x05\x12\x1e\n\x16special_industry_style\x18$ \x01(\x05\x12\x17\n\x0f\x65nable_h5_alert\x18% \x01(\x08\x12\x1e\n\x16macro_replace_priority\x18& \x01(\x05\x12\x1c\n\x14\x66\x65\x65\x64\x62\x61\x63k_panel_style\x18\' \x01(\x05\x12\x14\n\x0c\x61ppstore_url\x18( \x01(\t\x12\x1a\n\x12\x65nable_h5_pre_load\x18) \x01(\x05\x12\x17\n\x0fh5_pre_load_url\x18* \x01(\t\x12\x18\n\x10\x63m_from_track_id\x18+ \x01(\t\"y\n\nAdCoverDto\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04loop\x18\x02 \x01(\x05\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x13\n\x0breport_urls\x18\x04 \x03(\t\x12\x14\n\x0cimage_height\x18\x05 \x01(\x05\x12\x13\n\x0bimage_width\x18\x06 \x01(\x05\"\x8b\x02\n\x05\x41\x64\x44to\x12\x13\n\x0b\x63reative_id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_cb\x18\x02 \x01(\t\x12\x30\n\x05\x65xtra\x18\x03 \x01(\x0b\x32!.bilibili.ad.v1.AdContentExtraDto\x12\x0f\n\x07\x63m_mark\x18\x04 \x01(\x05\x12\x13\n\x0btop_view_id\x18\x05 \x01(\x03\x12\x15\n\rcreative_type\x18\x06 \x01(\x05\x12\x11\n\tcard_type\x18\x07 \x01(\x05\x12\x16\n\x0e\x63reative_style\x18\x08 \x01(\x05\x12\r\n\x05is_ad\x18\t \x01(\x05\x12\x35\n\x10\x63reative_content\x18\n \x01(\x0b\x32\x1b.bilibili.ad.v1.CreativeDto\"\xb4\x01\n\x12\x41\x64\x46\x65\x65\x64\x62\x61\x63kPanelDto\x12\x17\n\x0fpanel_type_text\x18\x01 \x01(\t\x12G\n\x15\x66\x65\x65\x64\x62\x61\x63k_panel_detail\x18\x02 \x03(\x0b\x32(.bilibili.ad.v1.AdFeedbackPanelModuleDto\x12\r\n\x05toast\x18\x03 \x01(\t\x12\x15\n\ropen_rec_tips\x18\x04 \x01(\t\x12\x16\n\x0e\x63lose_rec_tips\x18\x05 \x01(\t\"\xc7\x01\n\x18\x41\x64\x46\x65\x65\x64\x62\x61\x63kPanelModuleDto\x12\x11\n\tmodule_id\x18\x01 \x01(\x05\x12\x10\n\x08icon_url\x18\x02 \x01(\t\x12\x11\n\tjump_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x41\n\x0fsecondary_panel\x18\x06 \x03(\x0b\x32(.bilibili.ad.v1.AdSecondFeedbackPanelDto\x12\x10\n\x08sub_text\x18\x07 \x01(\t\"N\n\tAdGoodDto\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x0e\n\x06sku_id\x18\x02 \x01(\x03\x12\x0f\n\x07shop_id\x18\x03 \x01(\x03\x12\x0f\n\x07sku_num\x18\x04 \x01(\x03\"1\n\nAdOgvEpDto\x12\x0c\n\x04\x65pid\x18\x01 \x01(\x03\x12\x15\n\rhas_recommend\x18\x02 \x01(\x08\"Y\n\rAdsControlDto\x12\x11\n\thas_danmu\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ids\x18\x02 \x03(\x03\x12\'\n\x03\x65ps\x18\x03 \x03(\x0b\x32\x1a.bilibili.ad.v1.AdOgvEpDto\";\n\x18\x41\x64SecondFeedbackPanelDto\x12\x11\n\treason_id\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\"D\n\x0e\x41\x64ShareInfoDto\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\"\x84\x01\n\x08\x41\x64verDto\x12\x10\n\x08\x61\x64ver_id\x18\x01 \x01(\x03\x12\x12\n\nadver_logo\x18\x02 \x01(\t\x12\x12\n\nadver_name\x18\x03 \x01(\t\x12\x12\n\nadver_type\x18\x04 \x01(\x05\x12\x16\n\x0e\x61\x64ver_page_url\x18\x05 \x01(\t\x12\x12\n\nadver_desc\x18\x06 \x01(\t\"\xee\x04\n\x12\x41ndroidGamePageRes\x12(\n\x07module1\x18\x01 \x01(\x0b\x32\x17.bilibili.ad.v1.Module1\x12(\n\x07module3\x18\x02 \x01(\x0b\x32\x17.bilibili.ad.v1.Module3\x12(\n\x07module4\x18\x03 \x01(\x0b\x32\x17.bilibili.ad.v1.Module4\x12(\n\x07module5\x18\x04 \x01(\x0b\x32\x17.bilibili.ad.v1.Module5\x12(\n\x07module6\x18\x05 \x01(\x0b\x32\x17.bilibili.ad.v1.Module6\x12(\n\x07module7\x18\x06 \x01(\x0b\x32\x17.bilibili.ad.v1.Module7\x12(\n\x07module8\x18\x07 \x01(\x0b\x32\x17.bilibili.ad.v1.Module8\x12(\n\x07module9\x18\x08 \x01(\x0b\x32\x17.bilibili.ad.v1.Module9\x12*\n\x08module10\x18\t \x01(\x0b\x32\x18.bilibili.ad.v1.Module10\x12*\n\x08module11\x18\n \x01(\x0b\x32\x18.bilibili.ad.v1.Module11\x12*\n\x08module12\x18\x0b \x01(\x0b\x32\x18.bilibili.ad.v1.Module12\x12*\n\x08module13\x18\x0c \x01(\x0b\x32\x18.bilibili.ad.v1.Module13\x12\x12\n\nmodule_seq\x18\r \x03(\x05\x12\x18\n\x10\x62\x61\x63kground_color\x18\x0e \x01(\t\x12*\n\x08module14\x18\x0f \x01(\x0b\x32\x18.bilibili.ad.v1.Module14\"(\n\nAndroidTag\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\"\x87\x02\n\rAppPackageDto\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08\x61pk_name\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x10\n\x08\x62ili_url\x18\x05 \x01(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65v_name\x18\x08 \x01(\t\x12\x10\n\x08\x61uth_url\x18\t \x01(\t\x12\x11\n\tauth_name\x18\n \x01(\t\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12\x14\n\x0cprivacy_name\x18\r \x01(\t\x12\x13\n\x0bprivacy_url\x18\x0e \x01(\t\"*\n\x08\x42ulletin\x12\x10\n\x08tag_text\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x9f\x01\n\x07\x43omment\x12\x14\n\x0cgame_base_id\x18\x01 \x01(\x03\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x11\n\tuser_face\x18\x03 \x01(\t\x12\x12\n\nuser_level\x18\x04 \x01(\x05\x12\x12\n\ncomment_no\x18\x05 \x01(\t\x12\r\n\x05grade\x18\x06 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\x10\n\x08up_count\x18\x08 \x01(\x05\"\x83\x02\n\x0b\x43reativeDto\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x11\n\timage_md5\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x11\n\tclick_url\x18\x06 \x01(\t\x12\x10\n\x08show_url\x18\x07 \x01(\t\x12\x10\n\x08video_id\x18\x08 \x01(\x03\x12\x15\n\rthumbnail_url\x18\t \x01(\t\x12\x19\n\x11thumbnail_url_md5\x18\n \x01(\t\x12\x10\n\x08logo_url\x18\x0b \x01(\t\x12\x10\n\x08logo_md5\x18\x0c \x01(\t\x12\x10\n\x08username\x18\r \x01(\t\"0\n\rCustomPlayUrl\x12\x11\n\tplay_time\x18\x01 \x01(\x05\x12\x0c\n\x04urls\x18\x02 \x03(\t\"\xcd\x01\n\x0c\x46orwardReply\x12\x12\n\ncomment_id\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x16\n\x0ehighlight_text\x18\x03 \x01(\t\x12\x1d\n\x15highlight_prefix_icon\x18\x04 \x01(\t\x12\x12\n\ncallup_url\x18\x05 \x01(\t\x12\x10\n\x08jump_url\x18\x06 \x01(\t\x12\x11\n\tjump_type\x18\x07 \x01(\x05\x12\x13\n\x0b\x61uthor_name\x18\x08 \x01(\t\x12\x13\n\x0b\x61uthor_icon\x18\t \x01(\t\"C\n\x04Gift\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nnight_icon\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\xc7\x01\n\x0eIosGamePageRes\x12\x0c\n\x04logo\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nsub_titile\x18\x03 \x01(\t\x12\x11\n\timage_url\x18\x04 \x03(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x30\n\x0bgame_button\x18\x06 \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12\r\n\x05grade\x18\x07 \x01(\x01\x12\x10\n\x08rank_num\x18\x08 \x01(\t\x12\x11\n\trank_name\x18\t \x01(\t\"{\n\x07Module1\x12\x11\n\tgame_name\x18\x01 \x01(\t\x12\x11\n\tgame_icon\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65veloper_input_name\x18\x03 \x01(\t\x12,\n\x08tag_list\x18\x04 \x03(\x0b\x32\x1a.bilibili.ad.v1.AndroidTag\"Q\n\x07Module3\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x35\n\x0equality_params\x18\x03 \x03(\x0b\x32\x1d.bilibili.ad.v1.QualityParmas\"i\n\x07Module4\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x10\n\x08gift_num\x18\x02 \x01(\x05\x12\x11\n\tgift_name\x18\x03 \x01(\t\x12\x15\n\rgift_icon_num\x18\x04 \x01(\x05\x12\x11\n\ticon_urls\x18\x05 \x03(\t\"0\n\x07Module5\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x14\n\x0cgame_summary\x18\x02 \x01(\t\"-\n\x07Module6\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x11\n\tgame_desc\x18\x02 \x01(\t\"M\n\x07Module7\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x31\n\x0cscreen_shots\x18\x02 \x03(\x0b\x32\x1b.bilibili.ad.v1.ScreenShots\",\n\x07Module8\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x10\n\x08tag_list\x18\x02 \x03(\t\"4\n\x07Module9\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x18\n\x10\x64\x65v_introduction\x18\x02 \x01(\t\"2\n\x08Module10\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x15\n\rlatest_update\x18\x02 \x01(\t\"Y\n\x08Module11\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x18\n\x10star_number_list\x18\x02 \x03(\x05\x12\x13\n\x0b\x63omment_str\x18\x03 \x01(\t\x12\r\n\x05grade\x18\x04 \x01(\x01\"y\n\x08Module12\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12-\n\x0c\x63omment_list\x18\x02 \x03(\x0b\x32\x17.bilibili.ad.v1.Comment\x12\x13\n\x0b\x63omment_num\x18\x03 \x01(\t\x12\x18\n\x10show_all_comment\x18\x04 \x01(\x08\"\xc8\x01\n\x08Module13\x12\x10\n\x08pkg_size\x18\x01 \x01(\x03\x12\x18\n\x10\x63ustomer_service\x18\x02 \x01(\t\x12\x0f\n\x07website\x18\x03 \x01(\t\x12\x11\n\tauthority\x18\x04 \x01(\t\x12\x0f\n\x07privacy\x18\x05 \x01(\t\x12\x16\n\x0e\x64\x65veloper_name\x18\x06 \x01(\t\x12\x13\n\x0bupdate_time\x18\x07 \x01(\t\x12\x14\n\x0cgame_version\x18\x08 \x01(\t\x12\x18\n\x10\x61ndroid_pkg_name\x18\t \x01(\t\"H\n\x08Module14\x12+\n\x0breward_list\x18\x01 \x03(\x0b\x32\x16.bilibili.ad.v1.Reward\x12\x0f\n\x07\x64isplay\x18\x02 \x01(\x08\"3\n\x10NotClickableArea\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\t\n\x01z\x18\x03 \x01(\x05\"b\n\x0bQualityInfo\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05is_bg\x18\x03 \x01(\x08\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\"p\n\rQualityParmas\x12\x12\n\nfirst_line\x18\x01 \x01(\t\x12\x13\n\x0bsecond_line\x18\x02 \x01(\t\x12\r\n\x05grade\x18\x03 \x01(\x01\x12\x11\n\trank_icon\x18\x04 \x01(\t\x12\x14\n\x0cquality_type\x18\x05 \x01(\x05\"S\n\x06Reward\x12\r\n\x05level\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0b\n\x03pic\x18\x04 \x01(\t\x12\r\n\x05reach\x18\x05 \x01(\x08\"F\n\x0bScreenShots\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0b\n\x03seq\x18\x04 \x01(\x05\"\x91\x02\n\x10SourceContentDto\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x13\n\x0bresource_id\x18\x03 \x01(\x05\x12\x11\n\tis_ad_loc\x18\x04 \x01(\x08\x12\x30\n\x0bserver_type\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x11\n\tclient_ip\x18\x06 \x01(\t\x12/\n\ncard_index\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\r\n\x05index\x18\x08 \x01(\x05\x12)\n\nad_content\x18\t \x01(\x0b\x32\x15.bilibili.ad.v1.AdDto\"\xe4\x01\n\rSubCardModule\x12\x14\n\x0csubcard_type\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x12\n\nrank_stars\x18\x04 \x01(\t\x12\x15\n\ramount_number\x18\x05 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12+\n\x06\x62utton\x18\x08 \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12*\n\ttag_infos\x18\t \x03(\x0b\x32\x17.bilibili.ad.v1.TagInfo\"\x8b\x06\n\x0cTab2ExtraDto\x12\x11\n\tcover_url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12+\n\x06\x62utton\x18\x05 \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12\x1c\n\x14\x61uto_animate_time_ms\x18\x06 \x01(\x05\x12\x14\n\x0c\x65nable_click\x18\x07 \x01(\x08\x12\x11\n\tpanel_url\x18\x08 \x01(\t\x12\x39\n\x12\x64ownload_whitelist\x18\t \x03(\x0b\x32\x1d.bilibili.ad.v1.AppPackageDto\x12\x16\n\x0eopen_whitelist\x18\n \x03(\t\x12\x15\n\ruse_ad_web_v2\x18\x0b \x01(\x08\x12\"\n\x1a\x65nable_store_direct_launch\x18\x0c \x01(\x08\x12\x12\n\nsales_type\x18\r \x01(\x05\x12\"\n\x1alandingpage_download_style\x18\x0f \x01(\x05\x12\x19\n\x11\x61ppstore_priority\x18\x10 \x01(\x05\x12\x14\n\x0c\x61ppstore_url\x18\x11 \x01(\t\x12\x1b\n\x13\x61ppstore_delay_time\x18\x12 \x01(\x05\x12\x17\n\x0fpage_cover_type\x18\x13 \x01(\x05\x12\x16\n\x0epage_pull_type\x18\x14 \x01(\x05\x12\x41\n\x15\x61ndroid_game_page_res\x18\x15 \x01(\x0b\x32\".bilibili.ad.v1.AndroidGamePageRes\x12\x39\n\x11ios_game_page_res\x18\x16 \x01(\x0b\x32\x1e.bilibili.ad.v1.IosGamePageRes\x12\x37\n\x0c\x61\x64_tag_style\x18\x17 \x01(\x0b\x32!.bilibili.ad.v1.AdBusinessMarkDto\x12:\n\x0e\x66\x65\x65\x64\x62\x61\x63k_panel\x18\x18 \x01(\x0b\x32\".bilibili.ad.v1.AdFeedbackPanelDto\x12\r\n\x05\x61\x64_cb\x18\x19 \x01(\t\x12\x10\n\x08url_type\x18\x1a \x01(\x05\"\xa6\x03\n\x0bTabExtraDto\x12\x0f\n\x07tab_url\x18\x01 \x01(\t\x12\"\n\x1a\x65nable_store_direct_launch\x18\x02 \x01(\x05\x12\x19\n\x11store_callup_card\x18\x03 \x01(\x05\x12\x12\n\nsales_type\x18\x04 \x01(\x05\x12\x39\n\x12\x64ownload_whitelist\x18\x05 \x03(\x0b\x32\x1d.bilibili.ad.v1.AppPackageDto\x12\x18\n\x10special_industry\x18\x06 \x01(\x08\x12\x1d\n\x15special_industry_tips\x18\x07 \x01(\t\x12\x16\n\x0eopen_whitelist\x18\x08 \x03(\t\x12\"\n\x1alandingpage_download_style\x18\t \x01(\x05\x12\x19\n\x11\x61ppstore_priority\x18\n \x01(\x05\x12\x15\n\ruse_ad_web_v2\x18\x0b \x01(\x08\x12\x1e\n\x16\x65nable_download_dialog\x18\x0c \x01(\x08\x12\x14\n\x0c\x61ppstore_url\x18\r \x01(\t\x12\x1b\n\x13\x61ppstore_delay_time\x18\x0e \x01(\x05\"X\n\nTabInfoDto\x12\x10\n\x08tab_name\x18\x01 \x01(\t\x12#\n\x05\x65xtra\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x13\n\x0btab_version\x18\x03 \x01(\x05\"\xaf\x01\n\x07TagInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\";\n\rWxProgramInfo\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.ad.v1.ad_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADAUTOPLAYVIDEODTO._serialized_start=103
  _ADAUTOPLAYVIDEODTO._serialized_end=374
  _ADBUSINESSMARKDTO._serialized_start=377
  _ADBUSINESSMARKDTO._serialized_end=643
  _ADBUTTONDTO._serialized_start=646
  _ADBUTTONDTO._serialized_end=850
  _ADCARDDTO._serialized_start=853
  _ADCARDDTO._serialized_end=2628
  _ADCONTENTEXTRADTO._serialized_start=2631
  _ADCONTENTEXTRADTO._serialized_end=3836
  _ADCOVERDTO._serialized_start=3838
  _ADCOVERDTO._serialized_end=3959
  _ADDTO._serialized_start=3962
  _ADDTO._serialized_end=4229
  _ADFEEDBACKPANELDTO._serialized_start=4232
  _ADFEEDBACKPANELDTO._serialized_end=4412
  _ADFEEDBACKPANELMODULEDTO._serialized_start=4415
  _ADFEEDBACKPANELMODULEDTO._serialized_end=4614
  _ADGOODDTO._serialized_start=4616
  _ADGOODDTO._serialized_end=4694
  _ADOGVEPDTO._serialized_start=4696
  _ADOGVEPDTO._serialized_end=4745
  _ADSCONTROLDTO._serialized_start=4747
  _ADSCONTROLDTO._serialized_end=4836
  _ADSECONDFEEDBACKPANELDTO._serialized_start=4838
  _ADSECONDFEEDBACKPANELDTO._serialized_end=4897
  _ADSHAREINFODTO._serialized_start=4899
  _ADSHAREINFODTO._serialized_end=4967
  _ADVERDTO._serialized_start=4970
  _ADVERDTO._serialized_end=5102
  _ANDROIDGAMEPAGERES._serialized_start=5105
  _ANDROIDGAMEPAGERES._serialized_end=5727
  _ANDROIDTAG._serialized_start=5729
  _ANDROIDTAG._serialized_end=5769
  _APPPACKAGEDTO._serialized_start=5772
  _APPPACKAGEDTO._serialized_end=6035
  _BULLETIN._serialized_start=6037
  _BULLETIN._serialized_end=6079
  _COMMENT._serialized_start=6082
  _COMMENT._serialized_end=6241
  _CREATIVEDTO._serialized_start=6244
  _CREATIVEDTO._serialized_end=6503
  _CUSTOMPLAYURL._serialized_start=6505
  _CUSTOMPLAYURL._serialized_end=6553
  _FORWARDREPLY._serialized_start=6556
  _FORWARDREPLY._serialized_end=6761
  _GIFT._serialized_start=6763
  _GIFT._serialized_end=6830
  _IOSGAMEPAGERES._serialized_start=6833
  _IOSGAMEPAGERES._serialized_end=7032
  _MODULE1._serialized_start=7034
  _MODULE1._serialized_end=7157
  _MODULE3._serialized_start=7159
  _MODULE3._serialized_end=7240
  _MODULE4._serialized_start=7242
  _MODULE4._serialized_end=7347
  _MODULE5._serialized_start=7349
  _MODULE5._serialized_end=7397
  _MODULE6._serialized_start=7399
  _MODULE6._serialized_end=7444
  _MODULE7._serialized_start=7446
  _MODULE7._serialized_end=7523
  _MODULE8._serialized_start=7525
  _MODULE8._serialized_end=7569
  _MODULE9._serialized_start=7571
  _MODULE9._serialized_end=7623
  _MODULE10._serialized_start=7625
  _MODULE10._serialized_end=7675
  _MODULE11._serialized_start=7677
  _MODULE11._serialized_end=7766
  _MODULE12._serialized_start=7768
  _MODULE12._serialized_end=7889
  _MODULE13._serialized_start=7892
  _MODULE13._serialized_end=8092
  _MODULE14._serialized_start=8094
  _MODULE14._serialized_end=8166
  _NOTCLICKABLEAREA._serialized_start=8168
  _NOTCLICKABLEAREA._serialized_end=8219
  _QUALITYINFO._serialized_start=8221
  _QUALITYINFO._serialized_end=8319
  _QUALITYPARMAS._serialized_start=8321
  _QUALITYPARMAS._serialized_end=8433
  _REWARD._serialized_start=8435
  _REWARD._serialized_end=8518
  _SCREENSHOTS._serialized_start=8520
  _SCREENSHOTS._serialized_end=8590
  _SOURCECONTENTDTO._serialized_start=8593
  _SOURCECONTENTDTO._serialized_end=8866
  _SUBCARDMODULE._serialized_start=8869
  _SUBCARDMODULE._serialized_end=9097
  _TAB2EXTRADTO._serialized_start=9100
  _TAB2EXTRADTO._serialized_end=9879
  _TABEXTRADTO._serialized_start=9882
  _TABEXTRADTO._serialized_end=10304
  _TABINFODTO._serialized_start=10306
  _TABINFODTO._serialized_end=10394
  _TAGINFO._serialized_start=10397
  _TAGINFO._serialized_end=10572
  _WXPROGRAMINFO._serialized_start=10574
  _WXPROGRAMINFO._serialized_end=10633
# @@protoc_insertion_point(module_scope)
