"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CompressType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CompressTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CompressType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unzip: _CompressType.ValueType  # 0
    """unzip"""
    Original: _CompressType.ValueType  # 1
    """不操作"""

class CompressType(_CompressType, metaclass=_CompressTypeEnumTypeWrapper):
    """"""

Unzip: CompressType.ValueType  # 0
"""unzip"""
Original: CompressType.ValueType  # 1
"""不操作"""
global___CompressType = CompressType

class _EnvType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EnvTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EnvType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown: _EnvType.ValueType  # 0
    """"""
    Release: _EnvType.ValueType  # 1
    """"""
    Test: _EnvType.ValueType  # 2
    """"""

class EnvType(_EnvType, metaclass=_EnvTypeEnumTypeWrapper):
    """"""

Unknown: EnvType.ValueType  # 0
""""""
Release: EnvType.ValueType  # 1
""""""
Test: EnvType.ValueType  # 2
""""""
global___EnvType = EnvType

class _IncrementType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IncrementTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IncrementType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Total: _IncrementType.ValueType  # 0
    """全量包"""
    Incremental: _IncrementType.ValueType  # 1
    """增量包"""

class IncrementType(_IncrementType, metaclass=_IncrementTypeEnumTypeWrapper):
    """"""

Total: IncrementType.ValueType  # 0
"""全量包"""
Incremental: IncrementType.ValueType  # 1
"""增量包"""
global___IncrementType = IncrementType

class _LevelType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LevelTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LevelType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Undefined: _LevelType.ValueType  # 0
    """"""
    High: _LevelType.ValueType  # 1
    """高 需立即下载"""
    Middle: _LevelType.ValueType  # 2
    """中 可以延迟下载"""
    Low: _LevelType.ValueType  # 3
    """低 仅在业务方使用到时由业务方手动进行下载"""

class LevelType(_LevelType, metaclass=_LevelTypeEnumTypeWrapper):
    """"""

Undefined: LevelType.ValueType  # 0
""""""
High: LevelType.ValueType  # 1
"""高 需立即下载"""
Middle: LevelType.ValueType  # 2
"""中 可以延迟下载"""
Low: LevelType.ValueType  # 3
"""低 仅在业务方使用到时由业务方手动进行下载"""
global___LevelType = LevelType

@typing_extensions.final
class ListReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_FIELD_NUMBER: builtins.int
    POOLS_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    env: builtins.str
    """"""
    @property
    def pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PoolReply]:
        """"""
    list_version: builtins.int
    """"""
    def __init__(
        self,
        *,
        env: builtins.str = ...,
        pools: collections.abc.Iterable[global___PoolReply] | None = ...,
        list_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "list_version", b"list_version", "pools", b"pools"]) -> None: ...

global___ListReply = ListReply

@typing_extensions.final
class ListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_NAME_FIELD_NUMBER: builtins.int
    MODULE_NAME_FIELD_NUMBER: builtins.int
    VERSION_LIST_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    SYS_VER_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    ARCH_FIELD_NUMBER: builtins.int
    LIST_VERSION_FIELD_NUMBER: builtins.int
    pool_name: builtins.str
    """"""
    module_name: builtins.str
    """"""
    @property
    def version_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VersionListReq]:
        """"""
    env: global___EnvType.ValueType
    """"""
    sys_ver: builtins.int
    """"""
    scale: builtins.int
    """"""
    arch: builtins.int
    """"""
    list_version: builtins.int
    """"""
    def __init__(
        self,
        *,
        pool_name: builtins.str = ...,
        module_name: builtins.str = ...,
        version_list: collections.abc.Iterable[global___VersionListReq] | None = ...,
        env: global___EnvType.ValueType = ...,
        sys_ver: builtins.int = ...,
        scale: builtins.int = ...,
        arch: builtins.int = ...,
        list_version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arch", b"arch", "env", b"env", "list_version", b"list_version", "module_name", b"module_name", "pool_name", b"pool_name", "scale", b"scale", "sys_ver", b"sys_ver", "version_list", b"version_list"]) -> None: ...

global___ListReq = ListReq

@typing_extensions.final
class ModuleReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    TOTAL_MD5_FIELD_NUMBER: builtins.int
    INCREMENT_FIELD_NUMBER: builtins.int
    IS_WIFI_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    FILE_TYPE_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    COMPRESS_FIELD_NUMBER: builtins.int
    PUBLISH_TIME_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    MODULE_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    FILE_ID_FIELD_NUMBER: builtins.int
    ZIP_CHECK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    version: builtins.int
    """"""
    url: builtins.str
    """"""
    md5: builtins.str
    """"""
    total_md5: builtins.str
    """"""
    increment: global___IncrementType.ValueType
    """"""
    is_wifi: builtins.bool
    """"""
    level: global___LevelType.ValueType
    """"""
    filename: builtins.str
    """"""
    file_type: builtins.str
    """"""
    file_size: builtins.int
    """"""
    compress: global___CompressType.ValueType
    """"""
    publish_time: builtins.int
    """"""
    pool_id: builtins.int
    """上报使用"""
    module_id: builtins.int
    """"""
    version_id: builtins.int
    """"""
    file_id: builtins.int
    """"""
    zip_check: builtins.bool
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.int = ...,
        url: builtins.str = ...,
        md5: builtins.str = ...,
        total_md5: builtins.str = ...,
        increment: global___IncrementType.ValueType = ...,
        is_wifi: builtins.bool = ...,
        level: global___LevelType.ValueType = ...,
        filename: builtins.str = ...,
        file_type: builtins.str = ...,
        file_size: builtins.int = ...,
        compress: global___CompressType.ValueType = ...,
        publish_time: builtins.int = ...,
        pool_id: builtins.int = ...,
        module_id: builtins.int = ...,
        version_id: builtins.int = ...,
        file_id: builtins.int = ...,
        zip_check: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compress", b"compress", "file_id", b"file_id", "file_size", b"file_size", "file_type", b"file_type", "filename", b"filename", "increment", b"increment", "is_wifi", b"is_wifi", "level", b"level", "md5", b"md5", "module_id", b"module_id", "name", b"name", "pool_id", b"pool_id", "publish_time", b"publish_time", "total_md5", b"total_md5", "url", b"url", "version", b"version", "version_id", b"version_id", "zip_check", b"zip_check"]) -> None: ...

global___ModuleReply = ModuleReply

@typing_extensions.final
class PoolReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModuleReply]:
        """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        modules: collections.abc.Iterable[global___ModuleReply] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["modules", b"modules", "name", b"name"]) -> None: ...

global___PoolReply = PoolReply

@typing_extensions.final
class VersionListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_NAME_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    pool_name: builtins.str
    """"""
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VersionReq]:
        """"""
    def __init__(
        self,
        *,
        pool_name: builtins.str = ...,
        versions: collections.abc.Iterable[global___VersionReq] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_name", b"pool_name", "versions", b"versions"]) -> None: ...

global___VersionListReq = VersionListReq

@typing_extensions.final
class VersionReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    module_name: builtins.str
    """"""
    version: builtins.int
    """"""
    def __init__(
        self,
        *,
        module_name: builtins.str = ...,
        version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_name", b"module_name", "version", b"version"]) -> None: ...

global___VersionReq = VersionReq
