"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AntiHarassmentLimit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AntiHarassmentLimitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AntiHarassmentLimit.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DefaultLimit: _AntiHarassmentLimit.ValueType  # 0
    """"""
    FollowLimit: _AntiHarassmentLimit.ValueType  # 1
    """"""
    ReFollowLimit: _AntiHarassmentLimit.ValueType  # 2
    """"""
    TwoWayFollow: _AntiHarassmentLimit.ValueType  # 3
    """"""
    AllLimit: _AntiHarassmentLimit.ValueType  # 4
    """"""

class AntiHarassmentLimit(_AntiHarassmentLimit, metaclass=_AntiHarassmentLimitEnumTypeWrapper):
    """"""

DefaultLimit: AntiHarassmentLimit.ValueType  # 0
""""""
FollowLimit: AntiHarassmentLimit.ValueType  # 1
""""""
ReFollowLimit: AntiHarassmentLimit.ValueType  # 2
""""""
TwoWayFollow: AntiHarassmentLimit.ValueType  # 3
""""""
AllLimit: AntiHarassmentLimit.ValueType  # 4
""""""
global___AntiHarassmentLimit = AntiHarassmentLimit

class _BizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    InvalidBizType: _BizType.ValueType  # 0
    """"""
    Im: _BizType.ValueType  # 1
    """"""
    Dm: _BizType.ValueType  # 2
    """"""
    Reply: _BizType.ValueType  # 3
    """"""
    ReplyMe: _BizType.ValueType  # 4
    """"""
    LikeMe: _BizType.ValueType  # 5
    """"""
    AtMe: _BizType.ValueType  # 6
    """"""

class BizType(_BizType, metaclass=_BizTypeEnumTypeWrapper):
    """"""

InvalidBizType: BizType.ValueType  # 0
""""""
Im: BizType.ValueType  # 1
""""""
Dm: BizType.ValueType  # 2
""""""
Reply: BizType.ValueType  # 3
""""""
ReplyMe: BizType.ValueType  # 4
""""""
LikeMe: BizType.ValueType  # 5
""""""
AtMe: BizType.ValueType  # 6
""""""
global___BizType = BizType

@typing_extensions.final
class AntiHarassmentInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIMIT_FIELD_NUMBER: builtins.int
    FOLLOW_TIME_LIMIT_SECOND_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    limit: builtins.int
    """"""
    follow_time_limit_second: builtins.int
    """"""
    expire_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        limit: builtins.int = ...,
        follow_time_limit_second: builtins.int = ...,
        expire_time: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire_time", b"expire_time", "follow_time_limit_second", b"follow_time_limit_second", "limit", b"limit"]) -> None: ...

global___AntiHarassmentInfo = AntiHarassmentInfo

@typing_extensions.final
class AntiHarassmentSetting(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    AUTO_LIMIT_FIELD_NUMBER: builtins.int
    IM_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    DM_FIELD_NUMBER: builtins.int
    REPLY_ME_FIELD_NUMBER: builtins.int
    LIKE_ME_FIELD_NUMBER: builtins.int
    AT_ME_FIELD_NUMBER: builtins.int
    AUTO_LIMIT_EXPIRE_TIME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    auto_limit: builtins.bool
    """"""
    @property
    def im(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def reply(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def dm(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def reply_me(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def like_me(self) -> global___AntiHarassmentInfo:
        """"""
    @property
    def at_me(self) -> global___AntiHarassmentInfo:
        """"""
    auto_limit_expire_time: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        auto_limit: builtins.bool = ...,
        im: global___AntiHarassmentInfo | None = ...,
        reply: global___AntiHarassmentInfo | None = ...,
        dm: global___AntiHarassmentInfo | None = ...,
        reply_me: global___AntiHarassmentInfo | None = ...,
        like_me: global___AntiHarassmentInfo | None = ...,
        at_me: global___AntiHarassmentInfo | None = ...,
        auto_limit_expire_time: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["at_me", b"at_me", "dm", b"dm", "im", b"im", "like_me", b"like_me", "reply", b"reply", "reply_me", b"reply_me"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["at_me", b"at_me", "auto_limit", b"auto_limit", "auto_limit_expire_time", b"auto_limit_expire_time", "dm", b"dm", "im", b"im", "like_me", b"like_me", "mid", b"mid", "reply", b"reply", "reply_me", b"reply_me"]) -> None: ...

global___AntiHarassmentSetting = AntiHarassmentSetting

@typing_extensions.final
class LoadAntiHarassmentSettingsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_TYPE_FIELD_NUMBER: builtins.int
    RECV_MID_FIELD_NUMBER: builtins.int
    SEND_MID_FIELD_NUMBER: builtins.int
    biz_type: builtins.int
    """"""
    recv_mid: builtins.int
    """"""
    send_mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        biz_type: builtins.int = ...,
        recv_mid: builtins.int = ...,
        send_mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_type", b"biz_type", "recv_mid", b"recv_mid", "send_mid", b"send_mid"]) -> None: ...

global___LoadAntiHarassmentSettingsReq = LoadAntiHarassmentSettingsReq

@typing_extensions.final
class LoadAntiHarassmentSettingsRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANTI_HARASSMENT_RET_FIELD_NUMBER: builtins.int
    ANTI_HARASSMENT_SETTING_FIELD_NUMBER: builtins.int
    SHOW_WINDOW_FIELD_NUMBER: builtins.int
    anti_harassment_ret: builtins.bool
    """"""
    @property
    def anti_harassment_setting(self) -> global___AntiHarassmentSetting:
        """"""
    show_window: builtins.int
    """"""
    def __init__(
        self,
        *,
        anti_harassment_ret: builtins.bool = ...,
        anti_harassment_setting: global___AntiHarassmentSetting | None = ...,
        show_window: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["anti_harassment_setting", b"anti_harassment_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["anti_harassment_ret", b"anti_harassment_ret", "anti_harassment_setting", b"anti_harassment_setting", "show_window", b"show_window"]) -> None: ...

global___LoadAntiHarassmentSettingsRsp = LoadAntiHarassmentSettingsRsp

@typing_extensions.final
class StoreAntiHarassmentSettingsReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIZ_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    ANTI_HARASSMENT_SETTING_FIELD_NUMBER: builtins.int
    biz_type: builtins.int
    """"""
    mid: builtins.int
    """"""
    @property
    def anti_harassment_setting(self) -> global___AntiHarassmentSetting:
        """"""
    def __init__(
        self,
        *,
        biz_type: builtins.int = ...,
        mid: builtins.int = ...,
        anti_harassment_setting: global___AntiHarassmentSetting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["anti_harassment_setting", b"anti_harassment_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["anti_harassment_setting", b"anti_harassment_setting", "biz_type", b"biz_type", "mid", b"mid"]) -> None: ...

global___StoreAntiHarassmentSettingsReq = StoreAntiHarassmentSettingsReq

@typing_extensions.final
class StoreAntiHarassmentSettingsRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StoreAntiHarassmentSettingsRsp = StoreAntiHarassmentSettingsRsp
