syntax = "proto3";

package bilibili.broadcast.message.main;

import "google/protobuf/empty.proto";

//
service NativePage {
    //
    rpc WatchNotify(google.protobuf.Empty) returns (stream NativePageEvent);
}

//
message NativePageEvent {
    // Native页ID
    int64 PageID = 1;
    //
    repeated EventItem Items = 2;
}

//
message EventItem {
    // 组件标识
    int64 ItemID = 1;
    // 组件类型
    string Type = 2;
    // 进度条数值
    int64 Num = 3;
    // 进度条展示数值
    string DisplayNum = 4;
    // h5的组件标识
    string WebKey = 5;
    // 活动统计维度
    // 0:用户维度 1:规则维度
    int64 dimension = 6;
}
