# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/im/interfaces/v1/im.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.im.type import im_pb2 as bilibili_dot_im_dot_type_dot_im__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"bilibili/im/interfaces/v1/im.proto\x12\x18\x62ilibili.im.interface.v1\x1a\x19\x62ilibili/im/type/im.proto\"\x17\n\x08\x44ummyReq\x12\x0b\n\x03idl\x18\x01 \x01(\r\"\x10\n\x08\x44ummyRspJ\x04\x08\x01\x10\x02\"G\n\x0b\x45motionInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x0f\n\x07gif_url\x18\x04 \x01(\t\"+\n\tMsgDetail\x12\x0f\n\x07msg_key\x18\x01 \x01(\x03\x12\r\n\x05seqno\x18\x02 \x01(\x03\"\x89\x01\n\x10MsgFeedUnreadRsp\x12\x46\n\x06unread\x18\x01 \x03(\x0b\x32\x36.bilibili.im.interface.v1.MsgFeedUnreadRsp.UnreadEntry\x1a-\n\x0bUnreadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"#\n\x0eReqAckAssisMsg\x12\x11\n\tack_seqno\x18\x01 \x01(\x04\"@\n\x0eReqAckSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\r\x12\x0c\n\x04size\x18\x03 \x01(\r\"\x0e\n\x0cReqBatRmSess\"\x17\n\x15ReqCloseClearUnreadUI\"m\n\tReqGetMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x03\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x37\n\nmsg_detail\x18\x03 \x03(\x0b\x32#.bilibili.im.interface.v1.MsgDetail\"\xc1\x01\n\x0eReqGetSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\r\x12\x14\n\x0csession_type\x18\x04 \x01(\r\x12\x15\n\runfollow_fold\x18\x05 \x01(\r\x12\x12\n\ngroup_fold\x18\x06 \x01(\r\x12\x11\n\tsort_rule\x18\x07 \x01(\r\x12\x15\n\rteenager_mode\x18\x08 \x01(\r\x12\x14\n\x0clessons_mode\x18\t \x01(\r\"Z\n\x16ReqGetSpecificSessions\x12@\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32\'.bilibili.im.interface.v1.SimpleSession\"6\n\x10ReqGroupAssisMsg\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\"-\n\x0bReqLiveInfo\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\"]\n\x0eReqNewSessions\x12\x10\n\x08\x62\x65gin_ts\x18\x01 \x01(\x04\x12\x0c\n\x04size\x18\x02 \x01(\r\x12\x15\n\rteenager_mode\x18\x03 \x01(\r\x12\x14\n\x0clessons_mode\x18\x04 \x01(\r\"6\n\x0fReqRelationSync\x12#\n\x1b\x63lient_relation_oplog_seqno\x18\x01 \x01(\x04\";\n\x10ReqRemoveSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"u\n\nReqSendMsg\x12\"\n\x03msg\x18\x01 \x01(\x0b\x32\x15.bilibili.im.type.Msg\x12\x0e\n\x06\x63ookie\x18\x02 \x01(\t\x12\x0f\n\x07\x63ookie2\x18\x03 \x01(\t\x12\x12\n\nerror_code\x18\x04 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x05 \x01(\t\"H\n\x10ReqSessionDetail\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0b\n\x03uid\x18\x03 \x01(\x04\"Q\n\x11ReqSessionDetails\x12<\n\x08sess_ids\x18\x01 \x03(\x0b\x32*.bilibili.im.interface.v1.ReqSessionDetail\"\x8d\x01\n\rReqSessionMsg\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\x05\x12\x11\n\tend_seqno\x18\x03 \x01(\x04\x12\x13\n\x0b\x62\x65gin_seqno\x18\x04 \x01(\x04\x12\x0c\n\x04size\x18\x05 \x01(\x05\x12\r\n\x05order\x18\x06 \x01(\x05\x12\x0e\n\x06\x64\x65v_id\x18\x07 \x01(\t\"E\n\tReqSetTop\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x0f\n\x07op_type\x18\x03 \x01(\r\"\x1c\n\x0cReqShareList\x12\x0c\n\x04size\x18\x01 \x01(\x05\"]\n\x14ReqShowClearUnreadUI\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"e\n\x0fReqSingleUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\"[\n\x17ReqSpecificSingleUnread\x12@\n\x0ftalker_sessions\x18\x01 \x03(\x0b\x32\'.bilibili.im.interface.v1.SimpleSession\"\"\n\nReqSyncAck\x12\x14\n\x0c\x63lient_seqno\x18\x01 \x01(\x04\"\xa3\x01\n\x0eReqTotalUnread\x12\x13\n\x0bunread_type\x18\x01 \x01(\x05\x12\x1a\n\x12show_unfollow_list\x18\x02 \x01(\x05\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x14\n\x0cshow_dustbin\x18\x04 \x01(\x05\x12\x17\n\x0fsingleunread_on\x18\x05 \x01(\x05\x12\x12\n\nmsgfeed_on\x18\x06 \x01(\x05\x12\x10\n\x08sysup_on\x18\x07 \x01(\x05\"J\n\x0cReqUpdateAck\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x11\n\tack_seqno\x18\x03 \x01(\x04\"D\n\x12ReqUpdateIntercept\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x11\n\ttalker_id\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x05\"\x16\n\x14ReqUpdateTotalUnread\"\x17\n\x15RspCloseClearUnreadUI\"/\n\tRspGetMsg\x12\"\n\x03msg\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\"4\n\x0bRspLiveInfo\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"(\n\x10RspMyGroupUnread\x12\x14\n\x0cunread_count\x18\x01 \x01(\r\"\xe6\x01\n\x0fRspRelationSync\x12\x0c\n\x04\x66ull\x18\x01 \x01(\x05\x12\x34\n\rrelation_logs\x18\x02 \x03(\x0b\x32\x1d.bilibili.im.type.RelationLog\x12\x35\n\x0b\x66riend_list\x18\x03 \x03(\x0b\x32 .bilibili.im.type.FriendRelation\x12#\n\x1bserver_relation_oplog_seqno\x18\x04 \x01(\x04\x12\x33\n\ngroup_list\x18\x05 \x03(\x0b\x32\x1f.bilibili.im.type.GroupRelation\"\xa0\x01\n\nRspSendMsg\x12\x0f\n\x07msg_key\x18\x01 \x01(\x04\x12\x36\n\x07\x65_infos\x18\x02 \x03(\x0b\x32%.bilibili.im.interface.v1.EmotionInfo\x12\x13\n\x0bmsg_content\x18\x03 \x01(\t\x12\x34\n\rkey_hit_infos\x18\x04 \x01(\x0b\x32\x1d.bilibili.im.type.KeyHitInfos\"F\n\x11RspSessionDetails\x12\x31\n\nsess_infos\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\"\xa8\x01\n\rRspSessionMsg\x12\'\n\x08messages\x18\x01 \x03(\x0b\x32\x15.bilibili.im.type.Msg\x12\x10\n\x08has_more\x18\x02 \x01(\x05\x12\x11\n\tmin_seqno\x18\x03 \x01(\x04\x12\x11\n\tmax_seqno\x18\x04 \x01(\x04\x12\x36\n\x07\x65_infos\x18\x05 \x03(\x0b\x32%.bilibili.im.interface.v1.EmotionInfo\"\xa2\x02\n\x0bRspSessions\x12\x33\n\x0csession_list\x18\x01 \x03(\x0b\x32\x1d.bilibili.im.type.SessionInfo\x12\x10\n\x08has_more\x18\x02 \x01(\r\x12\x1d\n\x15\x61nti_disturb_cleaning\x18\x03 \x01(\x08\x12\x1d\n\x15is_address_list_empty\x18\x04 \x01(\x05\x12H\n\nsystem_msg\x18\x05 \x03(\x0b\x32\x34.bilibili.im.interface.v1.RspSessions.SystemMsgEntry\x12\x12\n\nshow_level\x18\x06 \x01(\x08\x1a\x30\n\x0eSystemMsgEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"l\n\x0cRspShareList\x12@\n\x0csession_list\x18\x01 \x03(\x0b\x32*.bilibili.im.interface.v1.ShareSessionInfo\x12\x1a\n\x12IsAddressListEmpty\x18\x02 \x01(\x05\"5\n\x14RspShowClearUnreadUI\x12\x0f\n\x07\x64isplay\x18\x01 \x01(\x08\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xce\x01\n\x0fRspSingleUnread\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x04\x12\x15\n\rfollow_unread\x18\x02 \x01(\x04\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\r\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\x12\x1f\n\x17\x62iz_msg_unfollow_unread\x18\x06 \x01(\x03\x12\x1d\n\x15\x62iz_msg_follow_unread\x18\x07 \x01(\x03\"\xc8\x01\n\x17RspSpecificSingleUnread\x12_\n\x0ftalkerUnreadCnt\x18\x01 \x03(\x0b\x32\x46.bilibili.im.interface.v1.RspSpecificSingleUnread.TalkerUnreadCntEntry\x12\x14\n\x0c\x61llUnreadCnt\x18\x02 \x01(\x04\x1a\x36\n\x14TalkerUnreadCntEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"\x0c\n\nRspSyncAck\"\x95\x02\n\x0eRspTotalUnread\x12O\n\x15session_single_unread\x18\x01 \x01(\x0b\x32\x30.bilibili.im.interface.v1.SessionSingleUnreadRsp\x12\x43\n\x0fmsg_feed_unread\x18\x02 \x01(\x0b\x32*.bilibili.im.interface.v1.MsgFeedUnreadRsp\x12W\n\x1asys_msg_interface_last_msg\x18\x03 \x01(\x0b\x32\x33.bilibili.im.interface.v1.SysMsgInterfaceLastMsgRsp\x12\x14\n\x0ctotal_unread\x18\x04 \x01(\x05\"\x16\n\x14RspUpdateTotalUnread\"\x95\x01\n\x16SessionSingleUnreadRsp\x12\x17\n\x0funfollow_unread\x18\x01 \x01(\x03\x12\x15\n\rfollow_unread\x18\x02 \x01(\x03\x12\x19\n\x11unfollow_push_msg\x18\x03 \x01(\x05\x12\x18\n\x10\x64ustbin_push_msg\x18\x04 \x01(\x05\x12\x16\n\x0e\x64ustbin_unread\x18\x05 \x01(\x03\"g\n\x10ShareSessionInfo\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0ctalker_uname\x18\x02 \x01(\t\x12\x13\n\x0btalker_icon\x18\x03 \x01(\t\x12\x15\n\rofficial_type\x18\x04 \x01(\x05\"8\n\rSimpleSession\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\"T\n\x19SysMsgInterfaceLastMsgRsp\x12\x0e\n\x06unread\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\x03*8\n\tENUM_FOLD\x12\x0b\n\x07\x46OLD_NO\x10\x00\x12\x0c\n\x08\x46OLD_YES\x10\x01\x12\x10\n\x0c\x46OLD_UNKNOWN\x10\x02*r\n\x10\x45NUM_UNREAD_TYPE\x12\x13\n\x0fUNREAD_TYPE_ALL\x10\x00\x12\x16\n\x12UNREAD_TYPE_FOLLOW\x10\x01\x12\x18\n\x14UNREAD_TYPE_UNFOLLOW\x10\x02\x12\x17\n\x13UNREAD_TYPE_DUSTBIN\x10\x03*\x8a\x01\n\x0cSESSION_TYPE\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUN_FOLD_SESSION\x10\x01\x12\x1c\n\x18UN_FOLLOW_SINGLE_SESSION\x10\x02\x12\x14\n\x10MY_GROUP_SESSION\x10\x03\x12\x0f\n\x0b\x41LL_SESSION\x10\x04\x12\x13\n\x0f\x44USTBIN_SESSION\x10\x05\x32\xb5\x14\n\x0bImInterface\x12U\n\x07SendMsg\x12$.bilibili.im.interface.v1.ReqSendMsg\x1a$.bilibili.im.interface.v1.RspSendMsg\x12\x64\n\x0cSyncRelation\x12).bilibili.im.interface.v1.ReqRelationSync\x1a).bilibili.im.interface.v1.RspRelationSync\x12U\n\x07SyncAck\x12$.bilibili.im.interface.v1.ReqSyncAck\x1a$.bilibili.im.interface.v1.RspSyncAck\x12h\n\x14SyncFetchSessionMsgs\x12\'.bilibili.im.interface.v1.ReqSessionMsg\x1a\'.bilibili.im.interface.v1.RspSessionMsg\x12^\n\x0bGetSessions\x12(.bilibili.im.interface.v1.ReqGetSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12^\n\x0bNewSessions\x12(.bilibili.im.interface.v1.ReqNewSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12^\n\x0b\x41\x63kSessions\x12(.bilibili.im.interface.v1.ReqAckSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12W\n\tUpdateAck\x12&.bilibili.im.interface.v1.ReqUpdateAck\x1a\".bilibili.im.interface.v1.DummyRsp\x12Q\n\x06SetTop\x12#.bilibili.im.interface.v1.ReqSetTop\x1a\".bilibili.im.interface.v1.DummyRsp\x12_\n\rRemoveSession\x12*.bilibili.im.interface.v1.ReqRemoveSession\x1a\".bilibili.im.interface.v1.DummyRsp\x12\x64\n\x0cSingleUnread\x12).bilibili.im.interface.v1.ReqSingleUnread\x1a).bilibili.im.interface.v1.RspSingleUnread\x12_\n\rMyGroupUnread\x12\".bilibili.im.interface.v1.DummyReq\x1a*.bilibili.im.interface.v1.RspMyGroupUnread\x12Y\n\x0fUpdateUnflwRead\x12\".bilibili.im.interface.v1.DummyReq\x1a\".bilibili.im.interface.v1.DummyRsp\x12\x64\n\rGroupAssisMsg\x12*.bilibili.im.interface.v1.ReqGroupAssisMsg\x1a\'.bilibili.im.interface.v1.RspSessionMsg\x12[\n\x0b\x41\x63kAssisMsg\x12(.bilibili.im.interface.v1.ReqAckAssisMsg\x1a\".bilibili.im.interface.v1.DummyRsp\x12Z\n\rSessionDetail\x12*.bilibili.im.interface.v1.ReqSessionDetail\x1a\x1d.bilibili.im.type.SessionInfo\x12k\n\x0f\x42\x61tchSessDetail\x12+.bilibili.im.interface.v1.ReqSessionDetails\x1a+.bilibili.im.interface.v1.RspSessionDetails\x12]\n\x0f\x42\x61tchRmSessions\x12&.bilibili.im.interface.v1.ReqBatRmSess\x1a\".bilibili.im.interface.v1.DummyRsp\x12[\n\tShareList\x12&.bilibili.im.interface.v1.ReqShareList\x1a&.bilibili.im.interface.v1.RspShareList\x12|\n\x14SpecificSingleUnread\x12\x31.bilibili.im.interface.v1.ReqSpecificSingleUnread\x1a\x31.bilibili.im.interface.v1.RspSpecificSingleUnread\x12n\n\x13GetSpecificSessions\x12\x30.bilibili.im.interface.v1.ReqGetSpecificSessions\x1a%.bilibili.im.interface.v1.RspSessions\x12[\n\x0bGetLiveInfo\x12%.bilibili.im.interface.v1.ReqLiveInfo\x1a%.bilibili.im.interface.v1.RspLiveInfo\x12\x64\n\x0eGetTotalUnread\x12(.bilibili.im.interface.v1.ReqTotalUnread\x1a(.bilibili.im.interface.v1.RspTotalUnread\x12s\n\x11ShowClearUnreadUI\x12..bilibili.im.interface.v1.ReqShowClearUnreadUI\x1a..bilibili.im.interface.v1.RspShowClearUnreadUI\x12v\n\x12\x43loseClearUnreadUI\x12/.bilibili.im.interface.v1.ReqCloseClearUnreadUI\x1a/.bilibili.im.interface.v1.RspCloseClearUnreadUI\x12s\n\x11UpdateTotalUnread\x12..bilibili.im.interface.v1.ReqUpdateTotalUnread\x1a..bilibili.im.interface.v1.RspUpdateTotalUnreadb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.im.interfaces.v1.im_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._options = None
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_options = b'8\001'
  _RSPSESSIONS_SYSTEMMSGENTRY._options = None
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_options = b'8\001'
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._options = None
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_options = b'8\001'
  _ENUM_FOLD._serialized_start=4832
  _ENUM_FOLD._serialized_end=4888
  _ENUM_UNREAD_TYPE._serialized_start=4890
  _ENUM_UNREAD_TYPE._serialized_end=5004
  _SESSION_TYPE._serialized_start=5007
  _SESSION_TYPE._serialized_end=5145
  _DUMMYREQ._serialized_start=91
  _DUMMYREQ._serialized_end=114
  _DUMMYRSP._serialized_start=116
  _DUMMYRSP._serialized_end=132
  _EMOTIONINFO._serialized_start=134
  _EMOTIONINFO._serialized_end=205
  _MSGDETAIL._serialized_start=207
  _MSGDETAIL._serialized_end=250
  _MSGFEEDUNREADRSP._serialized_start=253
  _MSGFEEDUNREADRSP._serialized_end=390
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_start=345
  _MSGFEEDUNREADRSP_UNREADENTRY._serialized_end=390
  _REQACKASSISMSG._serialized_start=392
  _REQACKASSISMSG._serialized_end=427
  _REQACKSESSIONS._serialized_start=429
  _REQACKSESSIONS._serialized_end=493
  _REQBATRMSESS._serialized_start=495
  _REQBATRMSESS._serialized_end=509
  _REQCLOSECLEARUNREADUI._serialized_start=511
  _REQCLOSECLEARUNREADUI._serialized_end=534
  _REQGETMSG._serialized_start=536
  _REQGETMSG._serialized_end=645
  _REQGETSESSIONS._serialized_start=648
  _REQGETSESSIONS._serialized_end=841
  _REQGETSPECIFICSESSIONS._serialized_start=843
  _REQGETSPECIFICSESSIONS._serialized_end=933
  _REQGROUPASSISMSG._serialized_start=935
  _REQGROUPASSISMSG._serialized_end=989
  _REQLIVEINFO._serialized_start=991
  _REQLIVEINFO._serialized_end=1036
  _REQNEWSESSIONS._serialized_start=1038
  _REQNEWSESSIONS._serialized_end=1131
  _REQRELATIONSYNC._serialized_start=1133
  _REQRELATIONSYNC._serialized_end=1187
  _REQREMOVESESSION._serialized_start=1189
  _REQREMOVESESSION._serialized_end=1248
  _REQSENDMSG._serialized_start=1250
  _REQSENDMSG._serialized_end=1367
  _REQSESSIONDETAIL._serialized_start=1369
  _REQSESSIONDETAIL._serialized_end=1441
  _REQSESSIONDETAILS._serialized_start=1443
  _REQSESSIONDETAILS._serialized_end=1524
  _REQSESSIONMSG._serialized_start=1527
  _REQSESSIONMSG._serialized_end=1668
  _REQSETTOP._serialized_start=1670
  _REQSETTOP._serialized_end=1739
  _REQSHARELIST._serialized_start=1741
  _REQSHARELIST._serialized_end=1769
  _REQSHOWCLEARUNREADUI._serialized_start=1771
  _REQSHOWCLEARUNREADUI._serialized_end=1864
  _REQSINGLEUNREAD._serialized_start=1866
  _REQSINGLEUNREAD._serialized_end=1967
  _REQSPECIFICSINGLEUNREAD._serialized_start=1969
  _REQSPECIFICSINGLEUNREAD._serialized_end=2060
  _REQSYNCACK._serialized_start=2062
  _REQSYNCACK._serialized_end=2096
  _REQTOTALUNREAD._serialized_start=2099
  _REQTOTALUNREAD._serialized_end=2262
  _REQUPDATEACK._serialized_start=2264
  _REQUPDATEACK._serialized_end=2338
  _REQUPDATEINTERCEPT._serialized_start=2340
  _REQUPDATEINTERCEPT._serialized_end=2408
  _REQUPDATETOTALUNREAD._serialized_start=2410
  _REQUPDATETOTALUNREAD._serialized_end=2432
  _RSPCLOSECLEARUNREADUI._serialized_start=2434
  _RSPCLOSECLEARUNREADUI._serialized_end=2457
  _RSPGETMSG._serialized_start=2459
  _RSPGETMSG._serialized_end=2506
  _RSPLIVEINFO._serialized_start=2508
  _RSPLIVEINFO._serialized_end=2560
  _RSPMYGROUPUNREAD._serialized_start=2562
  _RSPMYGROUPUNREAD._serialized_end=2602
  _RSPRELATIONSYNC._serialized_start=2605
  _RSPRELATIONSYNC._serialized_end=2835
  _RSPSENDMSG._serialized_start=2838
  _RSPSENDMSG._serialized_end=2998
  _RSPSESSIONDETAILS._serialized_start=3000
  _RSPSESSIONDETAILS._serialized_end=3070
  _RSPSESSIONMSG._serialized_start=3073
  _RSPSESSIONMSG._serialized_end=3241
  _RSPSESSIONS._serialized_start=3244
  _RSPSESSIONS._serialized_end=3534
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_start=3486
  _RSPSESSIONS_SYSTEMMSGENTRY._serialized_end=3534
  _RSPSHARELIST._serialized_start=3536
  _RSPSHARELIST._serialized_end=3644
  _RSPSHOWCLEARUNREADUI._serialized_start=3646
  _RSPSHOWCLEARUNREADUI._serialized_end=3699
  _RSPSINGLEUNREAD._serialized_start=3702
  _RSPSINGLEUNREAD._serialized_end=3908
  _RSPSPECIFICSINGLEUNREAD._serialized_start=3911
  _RSPSPECIFICSINGLEUNREAD._serialized_end=4111
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_start=4057
  _RSPSPECIFICSINGLEUNREAD_TALKERUNREADCNTENTRY._serialized_end=4111
  _RSPSYNCACK._serialized_start=4113
  _RSPSYNCACK._serialized_end=4125
  _RSPTOTALUNREAD._serialized_start=4128
  _RSPTOTALUNREAD._serialized_end=4405
  _RSPUPDATETOTALUNREAD._serialized_start=4407
  _RSPUPDATETOTALUNREAD._serialized_end=4429
  _SESSIONSINGLEUNREADRSP._serialized_start=4432
  _SESSIONSINGLEUNREADRSP._serialized_end=4581
  _SHARESESSIONINFO._serialized_start=4583
  _SHARESESSIONINFO._serialized_end=4686
  _SIMPLESESSION._serialized_start=4688
  _SIMPLESESSION._serialized_end=4744
  _SYSMSGINTERFACELASTMSGRSP._serialized_start=4746
  _SYSMSGINTERFACELASTMSGRSP._serialized_end=4830
  _IMINTERFACE._serialized_start=5148
  _IMINTERFACE._serialized_end=7761
# @@protoc_insertion_point(module_scope)
