"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Item(google.protobuf.message.Message):
    """排行榜列表项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAVOURITE_FIELD_NUMBER: builtins.int
    PUB_DATE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    RNAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PTS_FIELD_NUMBER: builtins.int
    COOPERATION_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    FOLLOWER_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    CHILDREN_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    cover: builtins.str
    """封面url"""
    param: builtins.str
    """参数(稿件avid)"""
    uri: builtins.str
    """跳转uri"""
    redirect_url: builtins.str
    """重定向url"""
    goto: builtins.str
    """跳转类型
    av:视频稿件
    """
    play: builtins.int
    """播放数"""
    danmaku: builtins.int
    """弹幕数"""
    mid: builtins.int
    """UP主mid"""
    name: builtins.str
    """UP主昵称"""
    face: builtins.str
    """UP主头像url"""
    reply: builtins.int
    """评论数"""
    favourite: builtins.int
    """收藏数"""
    pub_date: builtins.int
    """发布时间"""
    rid: builtins.int
    """分区tid"""
    rname: builtins.str
    """子分区名"""
    duration: builtins.int
    """视频总时长"""
    like: builtins.int
    """点赞数"""
    cid: builtins.int
    """1P cid"""
    pts: builtins.int
    """综合评分"""
    cooperation: builtins.str
    """合作视频文案"""
    attribute: builtins.int
    """属性位
    0:未关注 1:已关注
    """
    follower: builtins.int
    """UP主粉丝数"""
    @property
    def official_verify(self) -> global___OfficialVerify:
        """UP主认证信息"""
    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """同一UP收起子项列表"""
    @property
    def relation(self) -> global___Relation:
        """关系信息"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        param: builtins.str = ...,
        uri: builtins.str = ...,
        redirect_url: builtins.str = ...,
        goto: builtins.str = ...,
        play: builtins.int = ...,
        danmaku: builtins.int = ...,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        reply: builtins.int = ...,
        favourite: builtins.int = ...,
        pub_date: builtins.int = ...,
        rid: builtins.int = ...,
        rname: builtins.str = ...,
        duration: builtins.int = ...,
        like: builtins.int = ...,
        cid: builtins.int = ...,
        pts: builtins.int = ...,
        cooperation: builtins.str = ...,
        attribute: builtins.int = ...,
        follower: builtins.int = ...,
        official_verify: global___OfficialVerify | None = ...,
        children: collections.abc.Iterable[global___Item] | None = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official_verify", b"official_verify", "relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "children", b"children", "cid", b"cid", "cooperation", b"cooperation", "cover", b"cover", "danmaku", b"danmaku", "duration", b"duration", "face", b"face", "favourite", b"favourite", "follower", b"follower", "goto", b"goto", "like", b"like", "mid", b"mid", "name", b"name", "official_verify", b"official_verify", "param", b"param", "play", b"play", "pts", b"pts", "pub_date", b"pub_date", "redirect_url", b"redirect_url", "relation", b"relation", "reply", b"reply", "rid", b"rid", "rname", b"rname", "title", b"title", "uri", b"uri"]) -> None: ...

global___Item = Item

@typing_extensions.final
class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    -1:无认证 0:个人认证 1:机构认证
    """
    desc: builtins.str
    """认证描述"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        desc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "type", b"type"]) -> None: ...

global___OfficialVerify = OfficialVerify

@typing_extensions.final
class RankAllResultReq(google.protobuf.message.Message):
    """全站排行榜-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    order: builtins.str
    """必须为"all" """
    pn: builtins.int
    """页码
    默认1页
    """
    ps: builtins.int
    """每页项数
    默认100项，最大100
    """
    def __init__(
        self,
        *,
        order: builtins.str = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["order", b"order", "pn", b"pn", "ps", b"ps"]) -> None: ...

global___RankAllResultReq = RankAllResultReq

@typing_extensions.final
class RankListReply(google.protobuf.message.Message):
    """排行榜信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Item]:
        """排行榜列表"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___Item] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___RankListReply = RankListReply

@typing_extensions.final
class RankRegionResultReq(google.protobuf.message.Message):
    """分区排行榜-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    rid: builtins.int
    """一级分区tid(二级分区不可用)
    0:全站
    """
    pn: builtins.int
    """页码
    默认1页
    """
    ps: builtins.int
    """每页项数
    默认100项，最大100
    """
    def __init__(
        self,
        *,
        rid: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pn", b"pn", "ps", b"ps", "rid", b"rid"]) -> None: ...

global___RankRegionResultReq = RankRegionResultReq

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """关系信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    status: builtins.int
    """关系状态id
    1:未关注 2:已关注 3:被关注 4:互相关注
    """
    is_follow: builtins.int
    """是否关注"""
    is_followed: builtins.int
    """是否粉丝"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "is_followed", b"is_followed", "status", b"status"]) -> None: ...

global___Relation = Relation
