# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/dynamic/v1/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/dynamic/v1/dynamic.proto\x12\x17\x62ilibili.app.dynamic.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"{\n\x10\x41\x64\x64ressComponent\x12\x0e\n\x06nation\x18\x01 \x01(\t\x12\x10\n\x08province\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x10\n\x08\x64istrict\x18\x04 \x01(\t\x12\x0e\n\x06street\x18\x05 \x01(\t\x12\x15\n\rstreet_number\x18\x06 \x01(\t\"y\n\x06\x41\x64Info\x12\x13\n\x0bnation_code\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x64\x63ode\x18\x02 \x01(\t\x12\x11\n\tcity_code\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12)\n\x03gps\x18\x05 \x01(\x0b\x32\x1c.bilibili.app.dynamic.v1.Gps\"\x8e\x01\n\rCardCurrBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"\x8d\x01\n\x0e\x43\x61rdCurrSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"\xf6\x03\n\x07\x43\x61rdPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x36\n\nmedia_type\x18\x0b \x01(\x0e\x32\".bilibili.app.dynamic.v1.MediaType\x12\x37\n\x08sub_type\x18\x0c \x01(\x0e\x32%.bilibili.app.dynamic.v1.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x05\x12\x35\n\tdimension\x18\x0e \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x05\x12\x32\n\x06season\x18\x11 \x01(\x0b\x32\".bilibili.app.dynamic.v1.PGCSeason\"\xd5\x02\n\x07\x43\x61rdUGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x36\n\nmedia_type\x18\t \x01(\x0e\x32\".bilibili.app.dynamic.v1.MediaType\x12\x35\n\tdimension\x18\n \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x05\"<\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\r\n\x05\x63olor\x18\x03 \x01(\t\"q\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x31\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v1.DecoCardFan\"^\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\nemoji_type\x18\x04 \x01(\t\x12\x12\n\ngoods_type\x18\x05 \x01(\t\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"\xb4\x01\n\x0b\x44ynamicItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x11\n\titem_type\x18\x02 \x01(\t\x12\x30\n\x07modules\x18\x03 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Module\x12\x12\n\ndyn_id_str\x18\x04 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x05 \x01(\t\x12\x0e\n\x06r_type\x18\x06 \x01(\x05\x12\x10\n\x08has_fold\x18\x07 \x01(\x05\"E\n\x0f\x44ynDetailsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\"\x89\x01\n\rDynDetailsReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64ynamic_ids\x18\x02 \x01(\t\x12\n\n\x02qn\x18\x03 \x01(\x05\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x12\n\nforce_host\x18\x06 \x01(\x05\x12\r\n\x05\x66ourk\x18\x07 \x01(\x05\"P\n\x17\x44ynMixUpListSearchReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v1.MixUpListItem\"%\n\x15\x44ynMixUpListSearchReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"o\n\x19\x44ynMixUpListViewMoreReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v1.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\"\x9d\x01\n\x0e\x44ynOurCityItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12:\n\x07modules\x18\x04 \x03(\x0b\x32).bilibili.app.dynamic.v1.DynOurCityModule\x12\x0b\n\x03rid\x18\x05 \x01(\x03\x12\x12\n\ndebug_info\x18\x06 \x01(\t\"\xd8\x02\n\x10\x44ynOurCityModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x46\n\x0cmodule_cover\x18\x02 \x01(\x0b\x32..bilibili.app.dynamic.v1.DynOurCityModuleCoverH\x00\x12\x44\n\x0bmodule_desc\x18\x03 \x01(\x0b\x32-.bilibili.app.dynamic.v1.DynOurCityModuleDescH\x00\x12H\n\rmodule_author\x18\x04 \x01(\x0b\x32/.bilibili.app.dynamic.v1.DynOurCityModuleAuthorH\x00\x12H\n\rmodule_extend\x18\x05 \x01(\x0b\x32/.bilibili.app.dynamic.v1.DynOurCityModuleExtendH\x00\x42\r\n\x0bmodule_item\"N\n\x16\x44ynOurCityModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"\xf1\x01\n\x15\x44ynOurCityModuleCover\x12\x0e\n\x06\x63overs\x18\x01 \x03(\t\x12\r\n\x05style\x18\x02 \x01(\x05\x12\x19\n\x11\x63over_left_icon_1\x18\x03 \x01(\x05\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x05 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x06 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x07 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x08 \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"$\n\x14\x44ynOurCityModuleDesc\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\t\"z\n\x16\x44ynOurCityModuleExtend\x12\x0c\n\x04type\x18\x01 \x01(\t\x12H\n\nextend_lbs\x18\x02 \x01(\x0b\x32\x32.bilibili.app.dynamic.v1.DynOurCityModuleExtendLBSH\x00\x42\x08\n\x06\x65xtend\"W\n\x19\x44ynOurCityModuleExtendLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"\xca\x01\n\x0f\x44ynOurCityReply\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x10\n\x08has_more\x18\x02 \x01(\x05\x12\r\n\x05style\x18\x03 \x01(\x05\x12\x11\n\ttop_label\x18\x04 \x01(\t\x12\x35\n\x04list\x18\x05 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.DynOurCityItem\x12\x18\n\x10top_button_label\x18\x06 \x01(\t\x12\x0f\n\x07\x63ity_id\x18\x07 \x01(\x05\x12\x11\n\tcity_name\x18\x08 \x01(\t\"\x8b\x03\n\rDynOurCityReq\x12\x0f\n\x07\x63ity_id\x18\x01 \x01(\x03\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x16\n\x0eteenagers_mode\x18\x06 \x01(\x05\x12\n\n\x02qn\x18\x07 \x01(\x05\x12\r\n\x05\x66nver\x18\x08 \x01(\x05\x12\r\n\x05\x66nval\x18\t \x01(\x05\x12\x12\n\nforce_host\x18\n \x01(\x05\x12\r\n\x05\x66ourk\x18\x0b \x01(\x05\x12\x11\n\tlbs_state\x18\x0c \x01(\x05\x12\x14\n\x0crefresh_city\x18\r \x01(\r\x12\x32\n\x08\x65xp_conf\x18\x0e \x01(\x0b\x32 .bilibili.app.dynamic.v1.ExpConf\x12\x43\n\x0bplayer_args\x18\x0f \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x11\n\tcity_code\x18\x10 \x01(\x03\x12\x12\n\nbuild_time\x18\x11 \x01(\x03\"%\n\x13\x44ynOurCitySwitchReq\x12\x0e\n\x06switch\x18\x01 \x01(\x05\"\x1b\n\nDynRedItem\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\"\xa8\x01\n\x0b\x44ynRedReply\x12\x10\n\x08red_type\x18\x01 \x01(\t\x12\x39\n\x0c\x64yn_red_item\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v1.DynRedItem\x12\x13\n\x0b\x64\x65\x66\x61ult_tab\x18\x03 \x01(\t\x12\x37\n\tred_style\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v1.DynRedStyle\"C\n\tDynRedReq\x12\x36\n\ntab_offset\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v1.TabOffset\"\xa0\x01\n\x0b\x44ynRedStyle\x12\x0f\n\x07\x62g_type\x18\x01 \x01(\x05\x12\x13\n\x0b\x63orner_type\x18\x02 \x01(\x05\x12\x14\n\x0c\x64isplay_time\x18\x03 \x01(\x05\x12\x13\n\x0b\x63orner_mark\x18\x04 \x01(\t\x12\x32\n\x02up\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v1.DynRedStyleUp\x12\x0c\n\x04type\x18\x06 \x01(\x05\"*\n\rDynRedStyleUp\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"\xe7\x01\n\x06\x44ynTab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06\x62ubble\x18\x03 \x01(\t\x12\x11\n\tred_point\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ity_id\x18\x05 \x01(\x03\x12\x10\n\x08is_popup\x18\x06 \x01(\x05\x12-\n\x05popup\x18\x07 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v1.Popup\x12\x12\n\ndefaultTab\x18\x08 \x01(\x08\x12\x11\n\tsub_title\x18\t \x01(\t\x12\x0e\n\x06\x61nchor\x18\n \x01(\t\x12\x15\n\rinternal_test\x18\x0b \x01(\t\"?\n\x0b\x44ynTabReply\x12\x30\n\x07\x64yn_tab\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.DynTab\"#\n\tDynTabReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\"8\n\x0f\x44ynUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\"\x82\x01\n\x15\x44ynVideoPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x05\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\"\xbe\x01\n\x13\x44ynVideoPersonalReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x10\n\x08host_uid\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x12\n\nis_preload\x18\x05 \x01(\x05\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\"\xbf\x01\n\x0b\x44ynVideoReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x17\n\x0fupdate_baseline\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x14\n\x0crefresh_type\x18\x05 \x01(\x05\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\"\x9d\x01\n\x10\x44ynVideoReqReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x05\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x05\"*\n\x03\x45xp\x12\x10\n\x08\x65xp_name\x18\x01 \x01(\t\x12\x11\n\texp_group\x18\x02 \x01(\t\"I\n\x07\x45xpConf\x12\x12\n\nexp_enable\x18\x01 \x01(\x05\x12*\n\x04\x65xps\x18\x02 \x03(\x0b\x32\x1c.bilibili.app.dynamic.v1.Exp\"\x9a\x02\n\x06\x45xtend\x12\x0c\n\x04type\x18\x01 \x01(\t\x12?\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ExtInfoTopicH\x00\x12;\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ExtInfoLBSH\x00\x12;\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ExtInfoHotH\x00\x12=\n\rext_info_game\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v1.ExtInfoGameH\x00\x42\x08\n\x06\x65xtend\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"~\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12.\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v1.NewEP\"\x98\x01\n\rGeoCoderReply\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x44\n\x11\x61\x64\x64ress_component\x18\x02 \x01(\x0b\x32).bilibili.app.dynamic.v1.AddressComponent\x12\x30\n\x07\x61\x64_info\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v1.AdInfo\"5\n\x0bGeoCoderReq\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"\x1f\n\x03Gps\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"V\n\x08LikeInfo\x12\x39\n\tanimation\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v1.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x05\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"*\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xec\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12=\n\tlive_info\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v1.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v1.VipInfo\x12\x33\n\x08relation\x18\t \x01(\x0b\x32!.bilibili.app.dynamic.v1.Relation\x12\x16\n\x0epremiere_state\x18\n \x01(\x05\x12\x0b\n\x03uri\x18\x0b \x01(\t\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xf7\x05\n\x06Module\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12:\n\x0bmodule_fold\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ModuleFoldH\x00\x12>\n\rmodule_author\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ModuleAuthorH\x00\x12@\n\x0emodule_dynamic\x18\x04 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleDynamicH\x00\x12<\n\x0cmodule_state\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v1.ModuleStateH\x00\x12@\n\x0emodule_forward\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleForwardH\x00\x12>\n\rmodule_extend\x18\x07 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ModuleExtendH\x00\x12@\n\x0emodule_dispute\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleDisputeH\x00\x12:\n\x0bmodule_desc\x18\t \x01(\x0b\x32#.bilibili.app.dynamic.v1.ModuleDescH\x00\x12\x42\n\x0fmodule_likeUser\x18\n \x01(\x0b\x32\'.bilibili.app.dynamic.v1.ModuleLikeUserH\x00\x12\x41\n\rmodule_upList\x18\x0b \x01(\x0b\x32(.bilibili.app.dynamic.v1.ModuleDynUpListH\x00\x12\x46\n\x11module_followList\x18\x0c \x01(\x0b\x32).bilibili.app.dynamic.v1.ModuleFollowListH\x00\x42\r\n\x0bmodule_item\"\xa5\x01\n\x0cModuleAuthor\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x31\n\x06\x61uthor\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v1.UserInfo\x12<\n\rdecorate_card\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v1.DecorateCard\"@\n\nModuleDesc\x12\x32\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.Description\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x9e\x02\n\rModuleDynamic\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x34\n\x08\x63\x61rd_ugc\x18\x02 \x01(\x0b\x32 .bilibili.app.dynamic.v1.CardUGCH\x00\x12\x34\n\x08\x63\x61rd_pgc\x18\x03 \x01(\x0b\x32 .bilibili.app.dynamic.v1.CardPGCH\x00\x12\x43\n\x10\x63\x61rd_curr_season\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.CardCurrSeasonH\x00\x12\x41\n\x0f\x63\x61rd_curr_batch\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v1.CardCurrBatchH\x00\x42\x06\n\x04\x63\x61rd\"l\n\x0fModuleDynUpList\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\x10\n\x08show_all\x18\x02 \x01(\t\x12\x31\n\x04list\x18\x03 \x03(\x0b\x32#.bilibili.app.dynamic.v1.UpListItem\"?\n\x0cModuleExtend\x12/\n\x06\x65xtend\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Extend\"\xaf\x01\n\nModuleFold\x12\x11\n\tfold_type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x35\n\nfold_users\x18\x04 \x03(\x0b\x32!.bilibili.app.dynamic.v1.UserInfo\x12\x37\n\x0c\x66old_type_v2\x18\x05 \x01(\x0e\x32!.bilibili.app.dynamic.v1.FoldType\"`\n\x10ModuleFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x35\n\x04list\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.FollowListItem\"T\n\rModuleForward\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x30\n\x07modules\x18\x02 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Module\"]\n\x0eModuleLikeUser\x12\x35\n\nlike_users\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v1.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"\x98\x01\n\x0bModuleState\x12\x0e\n\x06repost\x18\x01 \x01(\x05\x12\x0c\n\x04like\x18\x02 \x01(\x05\x12\r\n\x05reply\x18\x03 \x01(\x05\x12\x34\n\tlike_info\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v1.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\t\n\x07NoReply\"\x07\n\x05NoReq\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\"\x19\n\x17OurCityClickReportReply\"V\n\x15OurCityClickReportReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ity_id\x18\x02 \x01(\x03\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lng\x18\x04 \x01(\x01\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"b\n\x13PlayerPreloadParams\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"1\n\x05Popup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"z\n\x08Relation\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v1.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"q\n\tShareInfo\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0b\n\x03mid\x18\x06 \x01(\x03\x12\x0c\n\x04name\x18\x07 \x01(\t\"z\n\nSVideoItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x36\n\x07modules\x18\x02 \x03(\x0b\x32%.bilibili.app.dynamic.v1.SVideoModule\x12\x12\n\ndyn_id_str\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x03\"\xc2\x02\n\x0cSVideoModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x44\n\rmodule_author\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v1.SVideoModuleAuthorH\x00\x12\x44\n\rmodule_player\x18\x03 \x01(\x0b\x32+.bilibili.app.dynamic.v1.SVideoModulePlayerH\x00\x12@\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32).bilibili.app.dynamic.v1.SVideoModuleDescH\x00\x12@\n\x0bmodule_stat\x18\x05 \x01(\x0b\x32).bilibili.app.dynamic.v1.SVideoModuleStatH\x00\x42\r\n\x0bmodule_item\"r\n\x12SVideoModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x10\n\x08pub_desc\x18\x04 \x01(\t\x12\x14\n\x0cis_attention\x18\x05 \x01(\x05\x12\x0b\n\x03uri\x18\x06 \x01(\t\"-\n\x10SVideoModuleDesc\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xa2\x01\n\x12SVideoModulePlayer\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0b\n\x03\x63id\x18\x05 \x01(\x03\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\x35\n\tdimension\x18\x07 \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\"\x86\x01\n\x10SVideoModuleStat\x12:\n\tstat_info\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.SVideoStatInfo\x12\x36\n\nshare_info\x18\x02 \x01(\x0b\x32\".bilibili.app.dynamic.v1.ShareInfo\"\x93\x01\n\x0bSVideoReply\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v1.SVideoItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x05\x12/\n\x03top\x18\x04 \x01(\x0b\x32\".bilibili.app.dynamic.v1.SVideoTop\"\xe9\x02\n\tSVideoReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.bilibili.app.dynamic.v1.SVideoType\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\n\n\x02qn\x18\x04 \x01(\x05\x12\r\n\x05\x66nver\x18\x05 \x01(\x05\x12\r\n\x05\x66nval\x18\x06 \x01(\x05\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x05\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x44\n\x0eplayer_preload\x18\x0b \x01(\x0b\x32,.bilibili.app.dynamic.v1.PlayerPreloadParams\x12\x11\n\tfocus_aid\x18\x0c \x01(\x03\x12\x43\n\x0bplayer_args\x18\r \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"J\n\x0eSVideoStatInfo\x12\x0c\n\x04icon\x18\x01 \x01(\x05\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x10\n\x08selected\x18\x03 \x01(\x05\x12\x0b\n\x03uri\x18\x04 \x01(\t\"(\n\tSVideoTop\x12\r\n\x05Title\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x65sc\x18\x02 \x01(\t\"(\n\tTabOffset\x12\x0b\n\x03tab\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\t\"I\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x05\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\"\xc9\x02\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x39\n\x08official\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.OfficialVerify\x12-\n\x03vip\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v1.VipInfo\x12/\n\x04live\x18\x06 \x01(\x0b\x32!.bilibili.app.dynamic.v1.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x35\n\x07pendant\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v1.UserPendant\x12\x35\n\tnameplate\x18\t \x01(\x0b\x32\".bilibili.app.dynamic.v1.Nameplate\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\xb6\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\"\x7f\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v1.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\"\x18\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t*/\n\x06\x42gType\x12\x13\n\x0f\x62g_type_default\x10\x00\x12\x10\n\x0c\x62g_type_face\x10\x01*S\n\nCornerType\x12\x14\n\x10\x63orner_type_none\x10\x00\x12\x14\n\x10\x63orner_type_text\x10\x01\x12\x19\n\x15\x63orner_type_animation\x10\x02*m\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZero\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05*L\n\tStyleType\x12\x13\n\x0fSTYLE_TYPE_NONE\x10\x00\x12\x13\n\x0fSTYLE_TYPE_LIVE\x10\x01\x12\x15\n\x11STYLE_TYPE_DYN_UP\x10\x02*Y\n\nSVideoType\x12\x0c\n\x08TypeNone\x10\x00\x12\x0f\n\x0bTypeDynamic\x10\x01\x12\x14\n\x10TypePopularIndex\x10\x02\x12\x16\n\x12TypePopularHotword\x10\x03*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05\x32\x8a\n\n\x07\x44ynamic\x12[\n\x08\x44ynVideo\x12$.bilibili.app.dynamic.v1.DynVideoReq\x1a).bilibili.app.dynamic.v1.DynVideoReqReply\x12^\n\nDynDetails\x12&.bilibili.app.dynamic.v1.DynDetailsReq\x1a(.bilibili.app.dynamic.v1.DynDetailsReply\x12R\n\x06SVideo\x12\".bilibili.app.dynamic.v1.SVideoReq\x1a$.bilibili.app.dynamic.v1.SVideoReply\x12R\n\x06\x44ynTab\x12\".bilibili.app.dynamic.v1.DynTabReq\x1a$.bilibili.app.dynamic.v1.DynTabReply\x12\x62\n\x10\x44ynOurCitySwitch\x12,.bilibili.app.dynamic.v1.DynOurCitySwitchReq\x1a .bilibili.app.dynamic.v1.NoReply\x12^\n\nDynOurCity\x12&.bilibili.app.dynamic.v1.DynOurCityReq\x1a(.bilibili.app.dynamic.v1.DynOurCityReply\x12p\n\x10\x44ynVideoPersonal\x12,.bilibili.app.dynamic.v1.DynVideoPersonalReq\x1a..bilibili.app.dynamic.v1.DynVideoPersonalReply\x12Z\n\x0c\x44ynUpdOffset\x12(.bilibili.app.dynamic.v1.DynUpdOffsetReq\x1a .bilibili.app.dynamic.v1.NoReply\x12R\n\x06\x44ynRed\x12\".bilibili.app.dynamic.v1.DynRedReq\x1a$.bilibili.app.dynamic.v1.DynRedReply\x12j\n\x14\x44ynMixUpListViewMore\x12\x1e.bilibili.app.dynamic.v1.NoReq\x1a\x32.bilibili.app.dynamic.v1.DynMixUpListViewMoreReply\x12v\n\x12\x44ynMixUpListSearch\x12..bilibili.app.dynamic.v1.DynMixUpListSearchReq\x1a\x30.bilibili.app.dynamic.v1.DynMixUpListSearchReply\x12v\n\x12OurCityClickReport\x12..bilibili.app.dynamic.v1.OurCityClickReportReq\x1a\x30.bilibili.app.dynamic.v1.OurCityClickReportReply\x12X\n\x08GeoCoder\x12$.bilibili.app.dynamic.v1.GeoCoderReq\x1a&.bilibili.app.dynamic.v1.GeoCoderReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.v1.dynamic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BGTYPE._serialized_start=12812
  _BGTYPE._serialized_end=12859
  _CORNERTYPE._serialized_start=12861
  _CORNERTYPE._serialized_end=12944
  _FOLDTYPE._serialized_start=12946
  _FOLDTYPE._serialized_end=13055
  _MEDIATYPE._serialized_start=13057
  _MEDIATYPE._serialized_end=13160
  _RELATIONSTATUS._serialized_start=13163
  _RELATIONSTATUS._serialized_end=13358
  _STYLETYPE._serialized_start=13360
  _STYLETYPE._serialized_end=13436
  _SVIDEOTYPE._serialized_start=13438
  _SVIDEOTYPE._serialized_end=13527
  _VIDEOSUBTYPE._serialized_start=13530
  _VIDEOSUBTYPE._serialized_end=13695
  _ADDRESSCOMPONENT._serialized_start=116
  _ADDRESSCOMPONENT._serialized_end=239
  _ADINFO._serialized_start=241
  _ADINFO._serialized_end=362
  _CARDCURRBATCH._serialized_start=365
  _CARDCURRBATCH._serialized_end=507
  _CARDCURRSEASON._serialized_start=510
  _CARDCURRSEASON._serialized_end=651
  _CARDPGC._serialized_start=654
  _CARDPGC._serialized_end=1156
  _CARDUGC._serialized_start=1159
  _CARDUGC._serialized_end=1500
  _DECOCARDFAN._serialized_start=1502
  _DECOCARDFAN._serialized_end=1562
  _DECORATECARD._serialized_start=1564
  _DECORATECARD._serialized_end=1677
  _DESCRIPTION._serialized_start=1679
  _DESCRIPTION._serialized_end=1773
  _DIMENSION._serialized_start=1775
  _DIMENSION._serialized_end=1833
  _DYNAMICITEM._serialized_start=1836
  _DYNAMICITEM._serialized_end=2016
  _DYNDETAILSREPLY._serialized_start=2018
  _DYNDETAILSREPLY._serialized_end=2087
  _DYNDETAILSREQ._serialized_start=2090
  _DYNDETAILSREQ._serialized_end=2227
  _DYNMIXUPLISTSEARCHREPLY._serialized_start=2229
  _DYNMIXUPLISTSEARCHREPLY._serialized_end=2309
  _DYNMIXUPLISTSEARCHREQ._serialized_start=2311
  _DYNMIXUPLISTSEARCHREQ._serialized_end=2348
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_start=2350
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_end=2461
  _DYNOURCITYITEM._serialized_start=2464
  _DYNOURCITYITEM._serialized_end=2621
  _DYNOURCITYMODULE._serialized_start=2624
  _DYNOURCITYMODULE._serialized_end=2968
  _DYNOURCITYMODULEAUTHOR._serialized_start=2970
  _DYNOURCITYMODULEAUTHOR._serialized_end=3048
  _DYNOURCITYMODULECOVER._serialized_start=3051
  _DYNOURCITYMODULECOVER._serialized_end=3292
  _DYNOURCITYMODULEDESC._serialized_start=3294
  _DYNOURCITYMODULEDESC._serialized_end=3330
  _DYNOURCITYMODULEEXTEND._serialized_start=3332
  _DYNOURCITYMODULEEXTEND._serialized_end=3454
  _DYNOURCITYMODULEEXTENDLBS._serialized_start=3456
  _DYNOURCITYMODULEEXTENDLBS._serialized_end=3543
  _DYNOURCITYREPLY._serialized_start=3546
  _DYNOURCITYREPLY._serialized_end=3748
  _DYNOURCITYREQ._serialized_start=3751
  _DYNOURCITYREQ._serialized_end=4146
  _DYNOURCITYSWITCHREQ._serialized_start=4148
  _DYNOURCITYSWITCHREQ._serialized_end=4185
  _DYNREDITEM._serialized_start=4187
  _DYNREDITEM._serialized_end=4214
  _DYNREDREPLY._serialized_start=4217
  _DYNREDREPLY._serialized_end=4385
  _DYNREDREQ._serialized_start=4387
  _DYNREDREQ._serialized_end=4454
  _DYNREDSTYLE._serialized_start=4457
  _DYNREDSTYLE._serialized_end=4617
  _DYNREDSTYLEUP._serialized_start=4619
  _DYNREDSTYLEUP._serialized_end=4661
  _DYNTAB._serialized_start=4664
  _DYNTAB._serialized_end=4895
  _DYNTABREPLY._serialized_start=4897
  _DYNTABREPLY._serialized_end=4960
  _DYNTABREQ._serialized_start=4962
  _DYNTABREQ._serialized_end=4997
  _DYNUPDOFFSETREQ._serialized_start=4999
  _DYNUPDOFFSETREQ._serialized_end=5055
  _DYNVIDEOPERSONALREPLY._serialized_start=5058
  _DYNVIDEOPERSONALREPLY._serialized_end=5188
  _DYNVIDEOPERSONALREQ._serialized_start=5191
  _DYNVIDEOPERSONALREQ._serialized_end=5381
  _DYNVIDEOREQ._serialized_start=5384
  _DYNVIDEOREQ._serialized_end=5575
  _DYNVIDEOREQREPLY._serialized_start=5578
  _DYNVIDEOREQREPLY._serialized_end=5735
  _EXP._serialized_start=5737
  _EXP._serialized_end=5779
  _EXPCONF._serialized_start=5781
  _EXPCONF._serialized_end=5854
  _EXTEND._serialized_start=5857
  _EXTEND._serialized_end=6139
  _EXTINFOGAME._serialized_start=6141
  _EXTINFOGAME._serialized_end=6196
  _EXTINFOHOT._serialized_start=6198
  _EXTINFOHOT._serialized_end=6252
  _EXTINFOLBS._serialized_start=6254
  _EXTINFOLBS._serialized_end=6326
  _EXTINFOTOPIC._serialized_start=6328
  _EXTINFOTOPIC._serialized_end=6384
  _FOLLOWLISTITEM._serialized_start=6386
  _FOLLOWLISTITEM._serialized_end=6512
  _GEOCODERREPLY._serialized_start=6515
  _GEOCODERREPLY._serialized_end=6667
  _GEOCODERREQ._serialized_start=6669
  _GEOCODERREQ._serialized_end=6722
  _GPS._serialized_start=6724
  _GPS._serialized_end=6755
  _LIKEANIMATION._serialized_start=6757
  _LIKEANIMATION._serialized_end=6836
  _LIKEINFO._serialized_start=6838
  _LIKEINFO._serialized_end=6924
  _LIKEUSER._serialized_start=6926
  _LIKEUSER._serialized_end=6977
  _LIVEINFO._serialized_start=6979
  _LIVEINFO._serialized_end=7021
  _MIXUPLISTITEM._serialized_start=7024
  _MIXUPLISTITEM._serialized_end=7388
  _MIXUPLISTLIVEITEM._serialized_start=7390
  _MIXUPLISTLIVEITEM._serialized_end=7455
  _MODULE._serialized_start=7458
  _MODULE._serialized_end=8217
  _MODULEAUTHOR._serialized_start=8220
  _MODULEAUTHOR._serialized_end=8385
  _MODULEDESC._serialized_start=8387
  _MODULEDESC._serialized_end=8451
  _MODULEDISPUTE._serialized_start=8453
  _MODULEDISPUTE._serialized_end=8510
  _MODULEDYNAMIC._serialized_start=8513
  _MODULEDYNAMIC._serialized_end=8799
  _MODULEDYNUPLIST._serialized_start=8801
  _MODULEDYNUPLIST._serialized_end=8909
  _MODULEEXTEND._serialized_start=8911
  _MODULEEXTEND._serialized_end=8974
  _MODULEFOLD._serialized_start=8977
  _MODULEFOLD._serialized_end=9152
  _MODULEFOLLOWLIST._serialized_start=9154
  _MODULEFOLLOWLIST._serialized_end=9250
  _MODULEFORWARD._serialized_start=9252
  _MODULEFORWARD._serialized_end=9336
  _MODULELIKEUSER._serialized_start=9338
  _MODULELIKEUSER._serialized_end=9431
  _MODULESTATE._serialized_start=9434
  _MODULESTATE._serialized_end=9586
  _NAMEPLATE._serialized_start=9588
  _NAMEPLATE._serialized_end=9696
  _NEWEP._serialized_start=9698
  _NEWEP._serialized_end=9752
  _NOREPLY._serialized_start=9754
  _NOREPLY._serialized_end=9763
  _NOREQ._serialized_start=9765
  _NOREQ._serialized_end=9772
  _OFFICIALVERIFY._serialized_start=9774
  _OFFICIALVERIFY._serialized_end=9836
  _OURCITYCLICKREPORTREPLY._serialized_start=9838
  _OURCITYCLICKREPORTREPLY._serialized_end=9863
  _OURCITYCLICKREPORTREQ._serialized_start=9865
  _OURCITYCLICKREPORTREQ._serialized_end=9951
  _PGCSEASON._serialized_start=9953
  _PGCSEASON._serialized_end=10012
  _PLAYERPRELOADPARAMS._serialized_start=10014
  _PLAYERPRELOADPARAMS._serialized_end=10112
  _POPUP._serialized_start=10114
  _POPUP._serialized_end=10163
  _RELATION._serialized_start=10165
  _RELATION._serialized_end=10287
  _SHAREINFO._serialized_start=10289
  _SHAREINFO._serialized_end=10402
  _SVIDEOITEM._serialized_start=10404
  _SVIDEOITEM._serialized_end=10526
  _SVIDEOMODULE._serialized_start=10529
  _SVIDEOMODULE._serialized_end=10851
  _SVIDEOMODULEAUTHOR._serialized_start=10853
  _SVIDEOMODULEAUTHOR._serialized_end=10967
  _SVIDEOMODULEDESC._serialized_start=10969
  _SVIDEOMODULEDESC._serialized_end=11014
  _SVIDEOMODULEPLAYER._serialized_start=11017
  _SVIDEOMODULEPLAYER._serialized_end=11179
  _SVIDEOMODULESTAT._serialized_start=11182
  _SVIDEOMODULESTAT._serialized_end=11316
  _SVIDEOREPLY._serialized_start=11319
  _SVIDEOREPLY._serialized_end=11466
  _SVIDEOREQ._serialized_start=11469
  _SVIDEOREQ._serialized_end=11830
  _SVIDEOSTATINFO._serialized_start=11832
  _SVIDEOSTATINFO._serialized_end=11906
  _SVIDEOTOP._serialized_start=11908
  _SVIDEOTOP._serialized_end=11948
  _TABOFFSET._serialized_start=11950
  _TABOFFSET._serialized_end=11990
  _UPLISTITEM._serialized_start=11992
  _UPLISTITEM._serialized_end=12065
  _USERINFO._serialized_start=12068
  _USERINFO._serialized_end=12397
  _USERPENDANT._serialized_start=12399
  _USERPENDANT._serialized_end=12470
  _VIDEOBADGE._serialized_start=12473
  _VIDEOBADGE._serialized_end=12655
  _VIPINFO._serialized_start=12657
  _VIPINFO._serialized_end=12784
  _VIPLABEL._serialized_start=12786
  _VIPLABEL._serialized_end=12810
  _DYNAMIC._serialized_start=13698
  _DYNAMIC._serialized_end=14988
# @@protoc_insertion_point(module_scope)
