syntax = "proto3";

package bilibili.metadata.network;

// 网络类型标识
// gRPC头部:x-bili-network-bin
message Network {
    // 网络类型
    NetworkType type = 1;
    // 免流类型
    TFType tf = 2;
    // 运营商
    string oid = 3;
}

// 网络类型
enum NetworkType {
    NT_UNKNOWN = 0; // 未知
    WIFI       = 1; // WIFI
    CELLULAR   = 2; // 蜂窝网络
    OFFLINE    = 3; // 未连接
    OTHERNET   = 4; // 其他网络
    ETHERNET   = 5; // 以太网
}

// 免流类型
enum TFType {
    TF_UNKNOWN = 0; // 正常计费
    U_CARD     = 1; // 联通卡
    U_PKG      = 2; // 联通包
    C_CARD     = 3; // 移动卡
    C_PKG      = 4; // 移动包
    T_CARD     = 5; // 电信卡
    T_PKG      = 6; // 电信包
}
