# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/show/rank/v1/rank.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/app/show/rank/v1/rank.proto\x12\x14\x62ilibili.app.show.v1\"\x8f\x04\n\x04Item\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\r\n\x05param\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x14\n\x0credirect_url\x18\x05 \x01(\t\x12\x0c\n\x04goto\x18\x06 \x01(\t\x12\x0c\n\x04play\x18\x07 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x08 \x01(\x05\x12\x0b\n\x03mid\x18\t \x01(\x03\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x0b \x01(\t\x12\r\n\x05reply\x18\x0c \x01(\x05\x12\x11\n\tfavourite\x18\r \x01(\x05\x12\x10\n\x08pub_date\x18\x0e \x01(\x03\x12\x0b\n\x03rid\x18\x0f \x01(\x05\x12\r\n\x05rname\x18\x10 \x01(\t\x12\x10\n\x08\x64uration\x18\x11 \x01(\x03\x12\x0c\n\x04like\x18\x12 \x01(\x05\x12\x0b\n\x03\x63id\x18\x13 \x01(\x03\x12\x0b\n\x03pts\x18\x14 \x01(\x03\x12\x13\n\x0b\x63ooperation\x18\x15 \x01(\t\x12\x11\n\tattribute\x18\x16 \x01(\x05\x12\x10\n\x08\x66ollower\x18\x17 \x01(\x03\x12=\n\x0fofficial_verify\x18\x18 \x01(\x0b\x32$.bilibili.app.show.v1.OfficialVerify\x12,\n\x08\x63hildren\x18\x19 \x03(\x0b\x32\x1a.bilibili.app.show.v1.Item\x12\x30\n\x08relation\x18\x1a \x01(\x0b\x32\x1e.bilibili.app.show.v1.Relation\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"9\n\x10RankAllResultReq\x12\r\n\x05order\x18\x01 \x01(\t\x12\n\n\x02pn\x18\x02 \x01(\x05\x12\n\n\x02ps\x18\x03 \x01(\x05\":\n\rRankListReply\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.bilibili.app.show.v1.Item\":\n\x13RankRegionResultReq\x12\x0b\n\x03rid\x18\x01 \x01(\x05\x12\n\n\x02pn\x18\x02 \x01(\x05\x12\n\n\x02ps\x18\x03 \x01(\x05\"B\n\x08Relation\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x32\xbc\x01\n\x04Rank\x12V\n\x07RankAll\x12&.bilibili.app.show.v1.RankAllResultReq\x1a#.bilibili.app.show.v1.RankListReply\x12\\\n\nRankRegion\x12).bilibili.app.show.v1.RankRegionResultReq\x1a#.bilibili.app.show.v1.RankListReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.show.rank.v1.rank_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ITEM._serialized_start=63
  _ITEM._serialized_end=590
  _OFFICIALVERIFY._serialized_start=592
  _OFFICIALVERIFY._serialized_end=636
  _RANKALLRESULTREQ._serialized_start=638
  _RANKALLRESULTREQ._serialized_end=695
  _RANKLISTREPLY._serialized_start=697
  _RANKLISTREPLY._serialized_end=755
  _RANKREGIONRESULTREQ._serialized_start=757
  _RANKREGIONRESULTREQ._serialized_end=815
  _RELATION._serialized_start=817
  _RELATION._serialized_end=883
  _RANK._serialized_start=886
  _RANK._serialized_end=1074
# @@protoc_insertion_point(module_scope)
