"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NativePageEvent(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGEID_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    PageID: builtins.int
    """Native页ID"""
    @property
    def Items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventItem]:
        """"""
    def __init__(
        self,
        *,
        PageID: builtins.int = ...,
        Items: collections.abc.Iterable[global___EventItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["Items", b"Items", "PageID", b"PageID"]) -> None: ...

global___NativePageEvent = NativePageEvent

@typing_extensions.final
class EventItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    DISPLAYNUM_FIELD_NUMBER: builtins.int
    WEBKEY_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    ItemID: builtins.int
    """组件标识"""
    Type: builtins.str
    """组件类型"""
    Num: builtins.int
    """进度条数值"""
    DisplayNum: builtins.str
    """进度条展示数值"""
    WebKey: builtins.str
    """h5的组件标识"""
    dimension: builtins.int
    """活动统计维度
    0:用户维度 1:规则维度
    """
    def __init__(
        self,
        *,
        ItemID: builtins.int = ...,
        Type: builtins.str = ...,
        Num: builtins.int = ...,
        DisplayNum: builtins.str = ...,
        WebKey: builtins.str = ...,
        dimension: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["DisplayNum", b"DisplayNum", "ItemID", b"ItemID", "Num", b"Num", "Type", b"Type", "WebKey", b"WebKey", "dimension", b"dimension"]) -> None: ...

global___EventItem = EventItem
