# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/laser.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/broadcast/v1/laser.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x1bgoogle/protobuf/empty.proto\"2\n\x12LaserLogUploadResp\x12\x0e\n\x06taskid\x18\x01 \x01(\x03\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\t2c\n\x05Laser\x12Z\n\x13WatchLogUploadEvent\x12\x16.google.protobuf.Empty\x1a).bilibili.broadcast.v1.LaserLogUploadResp0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.v1.laser_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LASERLOGUPLOADRESP._serialized_start=89
  _LASERLOGUPLOADRESP._serialized_end=139
  _LASER._serialized_start=141
  _LASER._serialized_end=240
# @@protoc_insertion_point(module_scope)
