"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TopPhotoType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopPhotoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopPhotoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _TopPhotoType.ValueType  # 0
    """"""
    PIC: _TopPhotoType.ValueType  # 1
    """"""
    ARCHIVE: _TopPhotoType.ValueType  # 2
    """"""

class TopPhotoType(_TopPhotoType, metaclass=_TopPhotoTypeEnumTypeWrapper):
    """"""

UNKNOWN: TopPhotoType.ValueType  # 0
""""""
PIC: TopPhotoType.ValueType  # 1
""""""
ARCHIVE: TopPhotoType.ValueType  # 2
""""""
global___TopPhotoType = TopPhotoType

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class OfficialReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    RCMD_FIELD_NUMBER: builtins.int
    IOS_URL_FIELD_NUMBER: builtins.int
    ANDROID_URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    uid: builtins.int
    """"""
    name: builtins.str
    """"""
    icon: builtins.str
    """"""
    scheme: builtins.str
    """"""
    rcmd: builtins.str
    """"""
    ios_url: builtins.str
    """"""
    android_url: builtins.str
    """"""
    button: builtins.str
    """"""
    deleted: builtins.str
    """"""
    mtime: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uid: builtins.int = ...,
        name: builtins.str = ...,
        icon: builtins.str = ...,
        scheme: builtins.str = ...,
        rcmd: builtins.str = ...,
        ios_url: builtins.str = ...,
        android_url: builtins.str = ...,
        button: builtins.str = ...,
        deleted: builtins.str = ...,
        mtime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["android_url", b"android_url", "button", b"button", "deleted", b"deleted", "icon", b"icon", "id", b"id", "ios_url", b"ios_url", "mtime", b"mtime", "name", b"name", "rcmd", b"rcmd", "scheme", b"scheme", "uid", b"uid"]) -> None: ...

global___OfficialReply = OfficialReply

@typing_extensions.final
class OfficialRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___OfficialRequest = OfficialRequest

@typing_extensions.final
class PhotoMall(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    NIGHT_IMG_FIELD_NUMBER: builtins.int
    IS_ACTIVATED_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    img: builtins.str
    """"""
    night_img: builtins.str
    """"""
    is_activated: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        img: builtins.str = ...,
        night_img: builtins.str = ...,
        is_activated: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "img", b"img", "is_activated", b"is_activated", "name", b"name", "night_img", b"night_img"]) -> None: ...

global___PhotoMall = PhotoMall

@typing_extensions.final
class PhotoMallListReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhotoMall]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___PhotoMall] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___PhotoMallListReply = PhotoMallListReply

@typing_extensions.final
class PhotoMallListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOBIAPP_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    mobiapp: builtins.str
    """"""
    mid: builtins.int
    """"""
    device: builtins.str
    """"""
    def __init__(
        self,
        *,
        mobiapp: builtins.str = ...,
        mid: builtins.int = ...,
        device: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device", b"device", "mid", b"mid", "mobiapp", b"mobiapp"]) -> None: ...

global___PhotoMallListReq = PhotoMallListReq

@typing_extensions.final
class PrivacyReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PrivacyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRIVACY_FIELD_NUMBER: builtins.int
    @property
    def privacy(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        privacy: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy", b"privacy"]) -> None: ...

global___PrivacyReply = PrivacyReply

@typing_extensions.final
class PrivacyRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___PrivacyRequest = PrivacyRequest

@typing_extensions.final
class SetTopPhotoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOBIAPP_FIELD_NUMBER: builtins.int
    I_D_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    mobiapp: builtins.str
    """"""
    i_d: builtins.int
    """"""
    mid: builtins.int
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        mobiapp: builtins.str = ...,
        i_d: builtins.int = ...,
        mid: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["i_d", b"i_d", "mid", b"mid", "mobiapp", b"mobiapp", "type", b"type"]) -> None: ...

global___SetTopPhotoReq = SetTopPhotoReq

@typing_extensions.final
class SpaceSettingReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_FIELD_NUMBER: builtins.int
    FAV_VIDEO_FIELD_NUMBER: builtins.int
    COINS_VIDEO_FIELD_NUMBER: builtins.int
    LIKES_VIDEO_FIELD_NUMBER: builtins.int
    BANGUMI_FIELD_NUMBER: builtins.int
    PLAYED_GAME_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    COMIC_FIELD_NUMBER: builtins.int
    B_BQ_FIELD_NUMBER: builtins.int
    DRESS_UP_FIELD_NUMBER: builtins.int
    DISABLE_FOLLOWING_FIELD_NUMBER: builtins.int
    LIVE_PLAYBACK_FIELD_NUMBER: builtins.int
    CLOSE_SPACE_MEDAL_FIELD_NUMBER: builtins.int
    ONLY_SHOW_WEARING_FIELD_NUMBER: builtins.int
    DISABLE_SHOW_SCHOOL_FIELD_NUMBER: builtins.int
    DISABLE_SHOW_NFT_FIELD_NUMBER: builtins.int
    channel: builtins.int
    """"""
    fav_video: builtins.int
    """"""
    coins_video: builtins.int
    """"""
    likes_video: builtins.int
    """"""
    bangumi: builtins.int
    """"""
    played_game: builtins.int
    """"""
    groups: builtins.int
    """"""
    comic: builtins.int
    """"""
    b_bq: builtins.int
    """"""
    dress_up: builtins.int
    """"""
    disable_following: builtins.int
    """"""
    live_playback: builtins.int
    """"""
    close_space_medal: builtins.int
    """"""
    only_show_wearing: builtins.int
    """"""
    disable_show_school: builtins.int
    """"""
    disable_show_nft: builtins.int
    """"""
    def __init__(
        self,
        *,
        channel: builtins.int = ...,
        fav_video: builtins.int = ...,
        coins_video: builtins.int = ...,
        likes_video: builtins.int = ...,
        bangumi: builtins.int = ...,
        played_game: builtins.int = ...,
        groups: builtins.int = ...,
        comic: builtins.int = ...,
        b_bq: builtins.int = ...,
        dress_up: builtins.int = ...,
        disable_following: builtins.int = ...,
        live_playback: builtins.int = ...,
        close_space_medal: builtins.int = ...,
        only_show_wearing: builtins.int = ...,
        disable_show_school: builtins.int = ...,
        disable_show_nft: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["b_bq", b"b_bq", "bangumi", b"bangumi", "channel", b"channel", "close_space_medal", b"close_space_medal", "coins_video", b"coins_video", "comic", b"comic", "disable_following", b"disable_following", "disable_show_nft", b"disable_show_nft", "disable_show_school", b"disable_show_school", "dress_up", b"dress_up", "fav_video", b"fav_video", "groups", b"groups", "likes_video", b"likes_video", "live_playback", b"live_playback", "only_show_wearing", b"only_show_wearing", "played_game", b"played_game"]) -> None: ...

global___SpaceSettingReply = SpaceSettingReply

@typing_extensions.final
class SpaceSettingReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___SpaceSettingReq = SpaceSettingReq

@typing_extensions.final
class TopPhoto(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMG_URL_FIELD_NUMBER: builtins.int
    NIGHT_IMG_URL_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    img_url: builtins.str
    """"""
    night_img_url: builtins.str
    """"""
    sid: builtins.int
    """"""
    def __init__(
        self,
        *,
        img_url: builtins.str = ...,
        night_img_url: builtins.str = ...,
        sid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["img_url", b"img_url", "night_img_url", b"night_img_url", "sid", b"sid"]) -> None: ...

global___TopPhoto = TopPhoto

@typing_extensions.final
class TopPhotoArc(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    show: builtins.bool
    """"""
    aid: builtins.int
    """"""
    pic: builtins.str
    """"""
    def __init__(
        self,
        *,
        show: builtins.bool = ...,
        aid: builtins.int = ...,
        pic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "pic", b"pic", "show", b"show"]) -> None: ...

global___TopPhotoArc = TopPhotoArc

@typing_extensions.final
class TopPhotoArcCancelReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___TopPhotoArcCancelReq = TopPhotoArcCancelReq

@typing_extensions.final
class TopPhotoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_PHOTO_FIELD_NUMBER: builtins.int
    TOP_PHOTO_ARC_FIELD_NUMBER: builtins.int
    @property
    def top_photo(self) -> global___TopPhoto:
        """"""
    @property
    def top_photo_arc(self) -> global___TopPhotoArc:
        """"""
    def __init__(
        self,
        *,
        top_photo: global___TopPhoto | None = ...,
        top_photo_arc: global___TopPhotoArc | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["top_photo", b"top_photo", "top_photo_arc", b"top_photo_arc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["top_photo", b"top_photo", "top_photo_arc", b"top_photo_arc"]) -> None: ...

global___TopPhotoReply = TopPhotoReply

@typing_extensions.final
class TopPhotoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOBIAPP_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOGIN_MID_FIELD_NUMBER: builtins.int
    mobiapp: builtins.str
    """"""
    mid: builtins.int
    """"""
    build: builtins.int
    """"""
    device: builtins.str
    """"""
    login_mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mobiapp: builtins.str = ...,
        mid: builtins.int = ...,
        build: builtins.int = ...,
        device: builtins.str = ...,
        login_mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "device", b"device", "login_mid", b"login_mid", "mid", b"mid", "mobiapp", b"mobiapp"]) -> None: ...

global___TopPhotoReq = TopPhotoReq

@typing_extensions.final
class UpActivityTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TAB_CONT_FIELD_NUMBER: builtins.int
    TAB_NAME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    state: builtins.int
    """"""
    tab_cont: builtins.int
    """"""
    tab_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        state: builtins.int = ...,
        tab_cont: builtins.int = ...,
        tab_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "state", b"state", "tab_cont", b"tab_cont", "tab_name", b"tab_name"]) -> None: ...

global___UpActivityTabReq = UpActivityTabReq

@typing_extensions.final
class UpActivityTabResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["success", b"success"]) -> None: ...

global___UpActivityTabResp = UpActivityTabResp

@typing_extensions.final
class UpRcmdBlackListReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpRcmdBlackListReply = UpRcmdBlackListReply

@typing_extensions.final
class UserTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TAB_NAME_FIELD_NUMBER: builtins.int
    TAB_ORDER_FIELD_NUMBER: builtins.int
    TAB_CONT_FIELD_NUMBER: builtins.int
    IS_DEFAULT_FIELD_NUMBER: builtins.int
    H5_LINK_FIELD_NUMBER: builtins.int
    tab_type: builtins.int
    """"""
    mid: builtins.int
    """"""
    tab_name: builtins.str
    """"""
    tab_order: builtins.int
    """"""
    tab_cont: builtins.int
    """"""
    is_default: builtins.int
    """"""
    h5_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        tab_type: builtins.int = ...,
        mid: builtins.int = ...,
        tab_name: builtins.str = ...,
        tab_order: builtins.int = ...,
        tab_cont: builtins.int = ...,
        is_default: builtins.int = ...,
        h5_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["h5_link", b"h5_link", "is_default", b"is_default", "mid", b"mid", "tab_cont", b"tab_cont", "tab_name", b"tab_name", "tab_order", b"tab_order", "tab_type", b"tab_type"]) -> None: ...

global___UserTabReply = UserTabReply

@typing_extensions.final
class UserTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    PLAT_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    plat: builtins.int
    """"""
    build: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        plat: builtins.int = ...,
        build: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "mid", b"mid", "plat", b"plat"]) -> None: ...

global___UserTabReq = UserTabReq

@typing_extensions.final
class WhitelistAddReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADD_OK_FIELD_NUMBER: builtins.int
    add_ok: builtins.bool
    """"""
    def __init__(
        self,
        *,
        add_ok: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["add_ok", b"add_ok"]) -> None: ...

global___WhitelistAddReply = WhitelistAddReply

@typing_extensions.final
class WhitelistAddReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    ETIME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    stime: builtins.int
    """"""
    etime: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        stime: builtins.int = ...,
        etime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["etime", b"etime", "mid", b"mid", "stime", b"stime"]) -> None: ...

global___WhitelistAddReq = WhitelistAddReq

@typing_extensions.final
class WhitelistReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_WHITE_FIELD_NUMBER: builtins.int
    is_white: builtins.bool
    """"""
    def __init__(
        self,
        *,
        is_white: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_white", b"is_white"]) -> None: ...

global___WhitelistReply = WhitelistReply

@typing_extensions.final
class WhitelistReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___WhitelistReq = WhitelistReq

@typing_extensions.final
class WhitelistUpReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_OK_FIELD_NUMBER: builtins.int
    up_ok: builtins.bool
    """"""
    def __init__(
        self,
        *,
        up_ok: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["up_ok", b"up_ok"]) -> None: ...

global___WhitelistUpReply = WhitelistUpReply

@typing_extensions.final
class WhitelistValidTimeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_WHITE_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    ETIME_FIELD_NUMBER: builtins.int
    is_white: builtins.bool
    """"""
    stime: builtins.int
    """"""
    etime: builtins.int
    """"""
    def __init__(
        self,
        *,
        is_white: builtins.bool = ...,
        stime: builtins.int = ...,
        etime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["etime", b"etime", "is_white", b"is_white", "stime", b"stime"]) -> None: ...

global___WhitelistValidTimeReply = WhitelistValidTimeReply
