# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.pangu.gallery.v1 import gallery_pb2 as bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class GalleryInterfaceStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/Ping',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UserInfo = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/UserInfo',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReply.FromString,
                )
        self.ListNFTByMid = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/ListNFTByMid',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReply.FromString,
                )
        self.ListOrderByMid = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/ListOrderByMid',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReply.FromString,
                )
        self.BasicInfo = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/BasicInfo',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReply.FromString,
                )
        self.UserCheck = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/UserCheck',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReply.FromString,
                )
        self.AgreePolicy = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/AgreePolicy',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReply.FromString,
                )
        self.GetLastPolicy = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/GetLastPolicy',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReply.FromString,
                )


class GalleryInterfaceServicer(object):
    """
    """

    def Ping(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserInfo(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNFTByMid(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrderByMid(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BasicInfo(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserCheck(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AgreePolicy(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLastPolicy(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GalleryInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UserInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.UserInfo,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReply.SerializeToString,
            ),
            'ListNFTByMid': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNFTByMid,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReply.SerializeToString,
            ),
            'ListOrderByMid': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrderByMid,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReply.SerializeToString,
            ),
            'BasicInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.BasicInfo,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReply.SerializeToString,
            ),
            'UserCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.UserCheck,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReply.SerializeToString,
            ),
            'AgreePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.AgreePolicy,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReply.SerializeToString,
            ),
            'GetLastPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLastPolicy,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.pangu.gallery.v1.GalleryInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GalleryInterface(object):
    """
    """

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/Ping',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/UserInfo',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNFTByMid(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/ListNFTByMid',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrderByMid(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/ListOrderByMid',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BasicInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/BasicInfo',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/UserCheck',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AgreePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/AgreePolicy',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLastPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/GetLastPolicy',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
