"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Metadata(google.protobuf.message.Message):
    """请求元数据
    gRPC头部:x-bili-metadata-bin
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    access_key: builtins.str
    """登录Token"""
    mobi_app: builtins.str
    """包类型"""
    device: builtins.str
    """运行设备"""
    build: builtins.int
    """构建id"""
    channel: builtins.str
    """APP分发渠道"""
    buvid: builtins.str
    """设备buvid"""
    platform: builtins.str
    """平台类型"""
    def __init__(
        self,
        *,
        access_key: builtins.str = ...,
        mobi_app: builtins.str = ...,
        device: builtins.str = ...,
        build: builtins.int = ...,
        channel: builtins.str = ...,
        buvid: builtins.str = ...,
        platform: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "build", b"build", "buvid", b"buvid", "channel", b"channel", "device", b"device", "mobi_app", b"mobi_app", "platform", b"platform"]) -> None: ...

global___Metadata = Metadata
