# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


class DynamicStub(object):
    """v2动态
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DynVideo = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVideo',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReply.FromString,
                )
        self.DynAll = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAll',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReply.FromString,
                )
        self.DynDetails = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynDetails',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReply.FromString,
                )
        self.DynVideoPersonal = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVideoPersonal',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReply.FromString,
                )
        self.DynVideoUpdOffset = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVideoUpdOffset',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoUpdOffsetReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynAdditionCommonFollow = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAdditionCommonFollow',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReply.FromString,
                )
        self.DynThumb = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynThumb',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynThumbReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynFakeCard = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynFakeCard',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReply.FromString,
                )
        self.DynRcmdUpExchange = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynRcmdUpExchange',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReply.FromString,
                )
        self.DynAllPersonal = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAllPersonal',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReply.FromString,
                )
        self.DynAllUpdOffset = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynAllUpdOffset',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllUpdOffsetReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynVote = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynVote',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReply.FromString,
                )
        self.DynMixUpListViewMore = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynMixUpListViewMore',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReply.FromString,
                )
        self.DynLight = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynLight',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReply.FromString,
                )
        self.DynDetail = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynDetail',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReply.FromString,
                )
        self.LikeList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/LikeList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReply.FromString,
                )
        self.RepostList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/RepostList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListRsp.FromString,
                )
        self.ReactionList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/ReactionList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReply.FromString,
                )
        self.DynSpace = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynSpace',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceRsp.FromString,
                )
        self.DynUnLoginRcmd = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynUnLoginRcmd',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReply.FromString,
                )
        self.DynServerDetails = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynServerDetails',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReply.FromString,
                )
        self.DynSearch = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynSearch',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReply.FromString,
                )
        self.SetDecision = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SetDecision',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetDecisionReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.AlumniDynamics = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/AlumniDynamics',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReply.FromString,
                )
        self.CampusRcmd = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusRcmd',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReply.FromString,
                )
        self.SubscribeCampus = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SubscribeCampus',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SubscribeCampusReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.SetRecentCampus = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SetRecentCampus',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetRecentCampusReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
                )
        self.DynTab = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynTab',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReply.FromString,
                )
        self.SchoolSearch = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SchoolSearch',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReply.FromString,
                )
        self.SchoolRecommend = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/SchoolRecommend',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReply.FromString,
                )
        self.DynSpaceSearchDetails = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/DynSpaceSearchDetails',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReply.FromString,
                )
        self.OfficialAccounts = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/OfficialAccounts',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReply.FromString,
                )
        self.OfficialDynamics = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/OfficialDynamics',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReply.FromString,
                )
        self.CampusRedDot = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusRedDot',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReply.FromString,
                )
        self.CampusRcmdFeed = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusRcmdFeed',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReply.FromString,
                )
        self.TopicSquare = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/TopicSquare',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReply.FromString,
                )
        self.TopicList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/TopicList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReply.FromString,
                )
        self.CampusMateLikeList = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusMateLikeList',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReply.FromString,
                )
        self.CampusFeedback = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusFeedback',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReply.FromString,
                )
        self.CampusBillboard = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusBillboard',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
                )
        self.CampusBillboardInternal = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusBillboardInternal',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillboardInternalReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
                )
        self.CampusTopicRcmdFeed = channel.unary_unary(
                '/bilibili.app.dynamic.v2.Dynamic/CampusTopicRcmdFeed',
                request_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReply.FromString,
                )


class DynamicServicer(object):
    """v2动态
    """

    def DynVideo(self, request, context):
        """动态视频页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAll(self, request, context):
        """动态综合页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynDetails(self, request, context):
        """批量动态id获取动态详情
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynVideoPersonal(self, request, context):
        """视频页最近访问 - 个人feed流
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynVideoUpdOffset(self, request, context):
        """视频页最近访问 - 标记已读
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAdditionCommonFollow(self, request, context):
        """动态通用附加卡-follow/取消follow
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynThumb(self, request, context):
        """动态点赞
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynFakeCard(self, request, context):
        """动态发布生成临时卡
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynRcmdUpExchange(self, request, context):
        """关注推荐up主换一换
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAllPersonal(self, request, context):
        """综合页最近访问 - 个人feed流
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynAllUpdOffset(self, request, context):
        """综合页最近访问 - 标记已读
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynVote(self, request, context):
        """投票操作接口
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynMixUpListViewMore(self, request, context):
        """网关调用 - 查看更多-列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynLight(self, request, context):
        """轻浏览
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynDetail(self, request, context):
        """动态详情页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LikeList(self, request, context):
        """点赞列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RepostList(self, request, context):
        """转发列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReactionList(self, request, context):
        """新版动态转发点赞列表 需要登录
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynSpace(self, request, context):
        """空间页动态
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynUnLoginRcmd(self, request, context):
        """未登录页分区UP主推荐
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynServerDetails(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynSearch(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDecision(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AlumniDynamics(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusRcmd(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeCampus(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRecentCampus(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynTab(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchoolSearch(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchoolRecommend(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DynSpaceSearchDetails(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OfficialAccounts(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OfficialDynamics(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusRedDot(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusRcmdFeed(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TopicSquare(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TopicList(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusMateLikeList(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusFeedback(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusBillboard(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusBillboardInternal(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampusTopicRcmdFeed(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DynamicServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DynVideo': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideo,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReply.SerializeToString,
            ),
            'DynAll': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAll,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReply.SerializeToString,
            ),
            'DynDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.DynDetails,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReply.SerializeToString,
            ),
            'DynVideoPersonal': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideoPersonal,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReply.SerializeToString,
            ),
            'DynVideoUpdOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVideoUpdOffset,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoUpdOffsetReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynAdditionCommonFollow': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAdditionCommonFollow,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReply.SerializeToString,
            ),
            'DynThumb': grpc.unary_unary_rpc_method_handler(
                    servicer.DynThumb,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynThumbReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynFakeCard': grpc.unary_unary_rpc_method_handler(
                    servicer.DynFakeCard,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReply.SerializeToString,
            ),
            'DynRcmdUpExchange': grpc.unary_unary_rpc_method_handler(
                    servicer.DynRcmdUpExchange,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReply.SerializeToString,
            ),
            'DynAllPersonal': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAllPersonal,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReply.SerializeToString,
            ),
            'DynAllUpdOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.DynAllUpdOffset,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllUpdOffsetReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynVote': grpc.unary_unary_rpc_method_handler(
                    servicer.DynVote,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReply.SerializeToString,
            ),
            'DynMixUpListViewMore': grpc.unary_unary_rpc_method_handler(
                    servicer.DynMixUpListViewMore,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReply.SerializeToString,
            ),
            'DynLight': grpc.unary_unary_rpc_method_handler(
                    servicer.DynLight,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReply.SerializeToString,
            ),
            'DynDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.DynDetail,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReply.SerializeToString,
            ),
            'LikeList': grpc.unary_unary_rpc_method_handler(
                    servicer.LikeList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReply.SerializeToString,
            ),
            'RepostList': grpc.unary_unary_rpc_method_handler(
                    servicer.RepostList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListRsp.SerializeToString,
            ),
            'ReactionList': grpc.unary_unary_rpc_method_handler(
                    servicer.ReactionList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReply.SerializeToString,
            ),
            'DynSpace': grpc.unary_unary_rpc_method_handler(
                    servicer.DynSpace,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceRsp.SerializeToString,
            ),
            'DynUnLoginRcmd': grpc.unary_unary_rpc_method_handler(
                    servicer.DynUnLoginRcmd,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReply.SerializeToString,
            ),
            'DynServerDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.DynServerDetails,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReply.SerializeToString,
            ),
            'DynSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.DynSearch,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReply.SerializeToString,
            ),
            'SetDecision': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDecision,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetDecisionReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'AlumniDynamics': grpc.unary_unary_rpc_method_handler(
                    servicer.AlumniDynamics,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReply.SerializeToString,
            ),
            'CampusRcmd': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusRcmd,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReply.SerializeToString,
            ),
            'SubscribeCampus': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeCampus,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SubscribeCampusReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'SetRecentCampus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRecentCampus,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetRecentCampusReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.SerializeToString,
            ),
            'DynTab': grpc.unary_unary_rpc_method_handler(
                    servicer.DynTab,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReply.SerializeToString,
            ),
            'SchoolSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.SchoolSearch,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReply.SerializeToString,
            ),
            'SchoolRecommend': grpc.unary_unary_rpc_method_handler(
                    servicer.SchoolRecommend,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReply.SerializeToString,
            ),
            'DynSpaceSearchDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.DynSpaceSearchDetails,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReply.SerializeToString,
            ),
            'OfficialAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.OfficialAccounts,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReply.SerializeToString,
            ),
            'OfficialDynamics': grpc.unary_unary_rpc_method_handler(
                    servicer.OfficialDynamics,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReply.SerializeToString,
            ),
            'CampusRedDot': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusRedDot,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReply.SerializeToString,
            ),
            'CampusRcmdFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusRcmdFeed,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReply.SerializeToString,
            ),
            'TopicSquare': grpc.unary_unary_rpc_method_handler(
                    servicer.TopicSquare,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReply.SerializeToString,
            ),
            'TopicList': grpc.unary_unary_rpc_method_handler(
                    servicer.TopicList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReply.SerializeToString,
            ),
            'CampusMateLikeList': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusMateLikeList,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReply.SerializeToString,
            ),
            'CampusFeedback': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusFeedback,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReply.SerializeToString,
            ),
            'CampusBillboard': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusBillboard,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.SerializeToString,
            ),
            'CampusBillboardInternal': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusBillboardInternal,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillboardInternalReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.SerializeToString,
            ),
            'CampusTopicRcmdFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.CampusTopicRcmdFeed,
                    request_deserializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReq.FromString,
                    response_serializer=bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.dynamic.v2.Dynamic', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Dynamic(object):
    """v2动态
    """

    @staticmethod
    def DynVideo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVideo',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAll',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynDetails',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynVideoPersonal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVideoPersonal',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoPersonalReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynVideoUpdOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVideoUpdOffset',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVideoUpdOffsetReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAdditionCommonFollow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAdditionCommonFollow',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAdditionCommonFollowReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynThumb(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynThumb',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynThumbReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynFakeCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynFakeCard',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynFakeCardReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynRcmdUpExchange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynRcmdUpExchange',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdUpExchangeReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAllPersonal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAllPersonal',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllPersonalReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynAllUpdOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynAllUpdOffset',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynAllUpdOffsetReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynVote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynVote',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynVoteReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynMixUpListViewMore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynMixUpListViewMore',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynMixUpListViewMoreReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynLight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynLight',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynLightReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynDetail',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynDetailReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LikeList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/LikeList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.LikeListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RepostList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/RepostList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.RepostListRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReactionList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/ReactionList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.ReactionListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynSpace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynSpace',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceRsp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynUnLoginRcmd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynUnLoginRcmd',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynRcmdReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynServerDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynServerDetails',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynServerDetailsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynSearch',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDecision(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SetDecision',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetDecisionReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AlumniDynamics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/AlumniDynamics',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.AlumniDynamicsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusRcmd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusRcmd',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubscribeCampus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SubscribeCampus',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SubscribeCampusReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRecentCampus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SetRecentCampus',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SetRecentCampusReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynTab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynTab',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynTabReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchoolSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SchoolSearch',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolSearchReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchoolRecommend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/SchoolRecommend',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.SchoolRecommendReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DynSpaceSearchDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/DynSpaceSearchDetails',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.DynSpaceSearchDetailsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OfficialAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/OfficialAccounts',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialAccountsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OfficialDynamics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/OfficialDynamics',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.OfficialDynamicsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusRedDot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusRedDot',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRedDotReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusRcmdFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusRcmdFeed',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusRcmdFeedReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TopicSquare(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/TopicSquare',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicSquareReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TopicList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/TopicList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.TopicListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusMateLikeList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusMateLikeList',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusMateLikeListReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusFeedback',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusFeedbackReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusBillboard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusBillboard',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusBillboardInternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusBillboardInternal',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillboardInternalReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusBillBoardReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CampusTopicRcmdFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.dynamic.v2.Dynamic/CampusTopicRcmdFeed',
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReq.SerializeToString,
            bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2.CampusTopicRcmdFeedReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
