"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetStudioListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOM_ID_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        room_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id", b"room_id"]) -> None: ...

global___GetStudioListReq = GetStudioListReq

@typing_extensions.final
class GetStudioListResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Pendants(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FRAME_FIELD_NUMBER: builtins.int
        BADGE_FIELD_NUMBER: builtins.int
        @property
        def frame(self) -> global___GetStudioListResp.Pendant:
            """"""
        @property
        def badge(self) -> global___GetStudioListResp.Pendant:
            """"""
        def __init__(
            self,
            *,
            frame: global___GetStudioListResp.Pendant | None = ...,
            badge: global___GetStudioListResp.Pendant | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["badge", b"badge", "frame", b"frame"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "frame", b"frame"]) -> None: ...

    @typing_extensions.final
    class Pendant(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        POSITION_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        DESC_FIELD_NUMBER: builtins.int
        name: builtins.str
        """"""
        position: builtins.int
        """"""
        value: builtins.str
        """"""
        desc: builtins.str
        """"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            position: builtins.int = ...,
            value: builtins.str = ...,
            desc: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "name", b"name", "position", b"position", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StudioMaster(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UID_FIELD_NUMBER: builtins.int
        ROOM_ID_FIELD_NUMBER: builtins.int
        UNAME_FIELD_NUMBER: builtins.int
        FACE_FIELD_NUMBER: builtins.int
        PENDANTS_FIELD_NUMBER: builtins.int
        TAG_FIELD_NUMBER: builtins.int
        TAG_TYPE_FIELD_NUMBER: builtins.int
        uid: builtins.int
        """"""
        room_id: builtins.int
        """"""
        uname: builtins.str
        """"""
        face: builtins.str
        """"""
        @property
        def pendants(self) -> global___GetStudioListResp.Pendants:
            """"""
        tag: builtins.str
        """"""
        tag_type: builtins.int
        """"""
        def __init__(
            self,
            *,
            uid: builtins.int = ...,
            room_id: builtins.int = ...,
            uname: builtins.str = ...,
            face: builtins.str = ...,
            pendants: global___GetStudioListResp.Pendants | None = ...,
            tag: builtins.str = ...,
            tag_type: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["pendants", b"pendants"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "pendants", b"pendants", "room_id", b"room_id", "tag", b"tag", "tag_type", b"tag_type", "uid", b"uid", "uname", b"uname"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    MASTER_LIST_FIELD_NUMBER: builtins.int
    status: builtins.int
    """"""
    @property
    def master_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetStudioListResp.StudioMaster]:
        """"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        master_list: collections.abc.Iterable[global___GetStudioListResp.StudioMaster] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["master_list", b"master_list", "status", b"status"]) -> None: ...

global___GetStudioListResp = GetStudioListResp
