# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/ogv/freya.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/broadcast/message/ogv/freya.proto\x12\x1e\x62ilibili.broadcast.message.ogv\"\xb9\x01\n\x15RoomMemberChangeEvent\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x10\n\x08owner_id\x18\x02 \x01(\x03\x12>\n\x07members\x18\x03 \x03(\x0b\x32-.bilibili.broadcast.message.ogv.UserInfoProto\x12=\n\x07message\x18\x04 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageProto\"\xd8\x01\n\x11ProgressSyncEvent\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x11\n\tseason_id\x18\x02 \x01(\x03\x12\x12\n\nepisode_id\x18\x03 \x01(\x03\x12:\n\x06status\x18\x04 \x01(\x0e\x32*.bilibili.broadcast.message.ogv.PlayStatus\x12\x10\n\x08progress\x18\x05 \x01(\x03\x12=\n\x07message\x18\x06 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageProto\"\x99\x01\n\x0fRoomUpdateEvent\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.bilibili.broadcast.message.ogv.RoomType\x12=\n\x07message\x18\x03 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageProto\"b\n\x10RoomDestroyEvent\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12=\n\x07message\x18\x04 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageProto\"\x9c\x01\n\x10RoomTriggerEvent\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12=\n\x07message\x18\x02 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageProto\x12<\n\x07trigger\x18\x03 \x01(\x0e\x32+.bilibili.broadcast.message.ogv.TriggerType\"\x9f\x02\n\rUserInfoProto\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x05\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x35\n\x03vip\x18\x06 \x01(\x0b\x32(.bilibili.broadcast.message.ogv.VipProto\x12?\n\x08official\x18\x07 \x01(\x0b\x32-.bilibili.broadcast.message.ogv.OfficialProto\x12=\n\x07pendant\x18\x08 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.PendantProto\x12\r\n\x05\x62uvid\x18\t \x01(\t\"5\n\x0cMessageProto\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\x05\"\x96\x01\n\x08VipProto\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x14\n\x0cvip_pay_type\x18\x04 \x01(\x05\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\x12\x18\n\x10\x61vatar_subscript\x18\x06 \x01(\x05\x12\x16\n\x0enickname_color\x18\x07 \x01(\t\"H\n\rOfficialProto\x12\x0c\n\x04role\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\"_\n\x0cPendantProto\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\x12\x15\n\rimage_enhance\x18\x05 \x01(\t\"\xcf\x02\n\x0cMessageEvent\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0e\n\x06msg_id\x18\x02 \x01(\x03\x12\n\n\x02ts\x18\x03 \x01(\x03\x12\x0b\n\x03oid\x18\x04 \x01(\x03\x12=\n\x06\x64omain\x18\x05 \x01(\x0e\x32-.bilibili.broadcast.message.ogv.MessageDomain\x12\x39\n\x04type\x18\x06 \x01(\x0e\x32+.bilibili.broadcast.message.ogv.MessageType\x12=\n\x07message\x18\x07 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageProto\x12;\n\x04user\x18\x08 \x01(\x0b\x32-.bilibili.broadcast.message.ogv.UserInfoProto\x12\x0f\n\x07msg_id2\x18\t \x01(\t\"q\n\x0fRemoveChatEvent\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0e\n\x06msg_id\x18\x02 \x01(\x03\x12=\n\x07message\x18\x03 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageProto\"\xe2\x04\n\x0e\x46reyaEventBody\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x11\n\twhite_mid\x18\x02 \x03(\x03\x12\x12\n\nignore_mid\x18\x03 \x03(\x03\x12N\n\rmember_change\x18\x04 \x01(\x0b\x32\x35.bilibili.broadcast.message.ogv.RoomMemberChangeEventH\x00\x12\x45\n\x08progress\x18\x05 \x01(\x0b\x32\x31.bilibili.broadcast.message.ogv.ProgressSyncEventH\x00\x12\x46\n\x0broom_update\x18\x06 \x01(\x0b\x32/.bilibili.broadcast.message.ogv.RoomUpdateEventH\x00\x12?\n\x07message\x18\x07 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.MessageEventH\x00\x12\x46\n\x0bremove_chat\x18\x08 \x01(\x0b\x32/.bilibili.broadcast.message.ogv.RemoveChatEventH\x00\x12H\n\x0croom_destroy\x18\t \x01(\x0b\x32\x30.bilibili.broadcast.message.ogv.RoomDestroyEventH\x00\x12H\n\x0croom_trigger\x18\n \x01(\x0b\x32\x30.bilibili.broadcast.message.ogv.RoomTriggerEventH\x00\x12\x13\n\x0bsequence_id\x18\x64 \x01(\x03\x42\x07\n\x05\x65vent**\n\nPlayStatus\x12\t\n\x05Pause\x10\x00\x12\x08\n\x04Play\x10\x01\x12\x07\n\x03\x45nd\x10\x02*!\n\x08RoomType\x12\x0b\n\x07Private\x10\x00\x12\x08\n\x04Open\x10\x01*?\n\rMessageDomain\x12\x11\n\rDefaultDomain\x10\x00\x12\x0b\n\x07RoomMid\x10\x01\x12\x0e\n\nSystemInfo\x10\x02*B\n\x0bMessageType\x12\x0f\n\x0b\x44\x65\x66\x61ultType\x10\x00\x12\x0f\n\x0b\x43hatMessage\x10\x01\x12\x11\n\rSystemMessage\x10\x02*/\n\x0bTriggerType\x12\x12\n\x0e\x44\x65\x66\x61ultTrigger\x10\x00\x12\x0c\n\x08Relation\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.ogv.freya_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLAYSTATUS._serialized_start=2635
  _PLAYSTATUS._serialized_end=2677
  _ROOMTYPE._serialized_start=2679
  _ROOMTYPE._serialized_end=2712
  _MESSAGEDOMAIN._serialized_start=2714
  _MESSAGEDOMAIN._serialized_end=2777
  _MESSAGETYPE._serialized_start=2779
  _MESSAGETYPE._serialized_end=2845
  _TRIGGERTYPE._serialized_start=2847
  _TRIGGERTYPE._serialized_end=2894
  _ROOMMEMBERCHANGEEVENT._serialized_start=79
  _ROOMMEMBERCHANGEEVENT._serialized_end=264
  _PROGRESSSYNCEVENT._serialized_start=267
  _PROGRESSSYNCEVENT._serialized_end=483
  _ROOMUPDATEEVENT._serialized_start=486
  _ROOMUPDATEEVENT._serialized_end=639
  _ROOMDESTROYEVENT._serialized_start=641
  _ROOMDESTROYEVENT._serialized_end=739
  _ROOMTRIGGEREVENT._serialized_start=742
  _ROOMTRIGGEREVENT._serialized_end=898
  _USERINFOPROTO._serialized_start=901
  _USERINFOPROTO._serialized_end=1188
  _MESSAGEPROTO._serialized_start=1190
  _MESSAGEPROTO._serialized_end=1243
  _VIPPROTO._serialized_start=1246
  _VIPPROTO._serialized_end=1396
  _OFFICIALPROTO._serialized_start=1398
  _OFFICIALPROTO._serialized_end=1470
  _PENDANTPROTO._serialized_start=1472
  _PENDANTPROTO._serialized_end=1567
  _MESSAGEEVENT._serialized_start=1570
  _MESSAGEEVENT._serialized_end=1905
  _REMOVECHATEVENT._serialized_start=1907
  _REMOVECHATEVENT._serialized_end=2020
  _FREYAEVENTBODY._serialized_start=2023
  _FREYAEVENTBODY._serialized_end=2633
# @@protoc_insertion_point(module_scope)
